commit stringlengths 40 40 | subject stringlengths 4 1.73k | repos stringlengths 5 127k | old_file stringlengths 2 751 | new_file stringlengths 2 751 | new_contents stringlengths 1 8.98k | old_contents stringlengths 0 6.59k | license stringclasses 13
values | lang stringclasses 23
values |
|---|---|---|---|---|---|---|---|---|
ce05d60ceb569d05b111e6eb45cefeb2d1b28612 | Add a comment. | bryancatanzaro/generics,bryancatanzaro/generics | test.cu | test.cu | #include "ldg.h"
#include <thrust/device_vector.h>
#include <iostream>
template<typename T>
struct non_pod {
T x;
T y;
T z;
__host__ __device__
non_pod() {}
__host__ __device__
non_pod(T a, T b, T c) : x(a), y(b), z(c) {}
friend std::ostream& operator<<(std::ostream& os, const non_pod... | #include "ldg.h"
#include <thrust/device_vector.h>
#include <iostream>
template<typename T>
struct non_pod {
T x;
T y;
T z;
__host__ __device__
non_pod() {}
__host__ __device__
non_pod(T a, T b, T c) : x(a), y(b), z(c) {}
friend std::ostream& operator<<(std::ostream& os, const non_pod... | bsd-3-clause | Cuda |
82adc93e69c0a6104d586ce471c21649306c3fc4 | Test clean-up | ROCm-Developer-Tools/HIP,ROCm-Developer-Tools/HIP,GPUOpen-ProfessionalCompute-Tools/HIP,ROCm-Developer-Tools/HIP,GPUOpen-ProfessionalCompute-Tools/HIP,ROCm-Developer-Tools/HIP,GPUOpen-ProfessionalCompute-Tools/HIP,GPUOpen-ProfessionalCompute-Tools/HIP,ROCm-Developer-Tools/HIP,GPUOpen-ProfessionalCompute-Tools/HIP | tests/hipify-clang/unit_tests/libraries/CUB/cub_03.cu | tests/hipify-clang/unit_tests/libraries/CUB/cub_03.cu | // RUN: %run_test hipify "%s" "%t" %hipify_args %clang_args
// CHECK: #include <hip/hip_runtime.h>
#include <iostream>
// CHECK: #include <hiprand.h>
#include <curand.h>
// CHECK: #include <hipcub/hipcub.hpp>
#include <cub/cub.cuh>
// using namespace hipcub;
using namespace cub;
// Simple CUDA kernel for computing ti... | // RUN: %run_test hipify "%s" "%t" %hipify_args %clang_args
// CHECK: #include <hip/hip_runtime.h>
#include <iostream>
// CHECK: #include <hiprand.h>
#include <curand.h>
// CHECK: #include <hipcub/hipcub.hpp>
#include <cub/cub.cuh>
#include <iostream>
// using namespace hipcub;
using namespace cub;
/**
* Simple CUDA... | mit | Cuda |
4a00b74b18b98c86cfecd54ac05b8fcc50713f91 | Fix sum | wichtounet/etl-gpu-blas,wichtounet/etl-gpu-blas | src/sum.cu | src/sum.cu | //=======================================================================
// Copyright (c) 2017 Baptiste Wicht
// Distributed under the terms of the MIT License.
// (See accompanying file LICENSE or copy at
// http://opensource.org/licenses/MIT)
//=======================================================================... | //=======================================================================
// Copyright (c) 2017 Baptiste Wicht
// Distributed under the terms of the MIT License.
// (See accompanying file LICENSE or copy at
// http://opensource.org/licenses/MIT)
//=======================================================================... | mit | Cuda |
7a87d5b5cb68814df4ada81441b54b66fa3aea99 | Test sequence algorithms with thrust::device in __device__ code. | xiongzhanblake/thrust,GrimDerp/thrust,dachziegel/thrust,sdalton1/thrust,jaredhoberock/thrust,thvasilo/thrust,zhenglaizhang/thrust,zeryx/thrust,raygit/thrust,jaredhoberock/thrust,andrewcorrigan/thrust-multi-permutation-iterator,jaredhoberock/thrust,dachziegel/thrust,arnabgho/thrust,zhenglaizhang/thrust,mohamed-ali/thrus... | testing/backend/cuda/sequence.cu | testing/backend/cuda/sequence.cu | #include <unittest/unittest.h>
#include <thrust/sequence.h>
#include <thrust/execution_policy.h>
template<typename ExecutionPolicy, typename Iterator>
__global__
void sequence_kernel(ExecutionPolicy exec, Iterator first, Iterator last)
{
thrust::sequence(exec, first, last);
}
template<typename ExecutionPolicy, ty... | #include <unittest/unittest.h>
#include <thrust/sequence.h>
#include <thrust/execution_policy.h>
template<typename Iterator>
__global__
void sequence_kernel(Iterator first, Iterator last)
{
thrust::sequence(thrust::seq, first, last);
}
template<typename Iterator, typename T>
__global__
void sequence_kernel(Iterat... | apache-2.0 | Cuda |
f075fe5c3681812d44dfe16a333e80ded981c19b | Disable new API until we work out a solution. | NVlabs/cub,NVIDIA/cub,NVlabs/CUB | cub/detail/device_synchronize.cuh | cub/detail/device_synchronize.cuh | /*
* Copyright 2021 NVIDIA Corporation
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law ... | /*
* Copyright 2021 NVIDIA Corporation
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law ... | bsd-3-clause | Cuda |
5e4c3f8ec319f582dd1757e5aede6174f1ee66da | Use newton.hpp in saxpy example | jaredhoberock/newton | examples/saxpy.cu | examples/saxpy.cu | #include <newton/newton.hpp>
#include <thrust/device_vector.h>
#include <thrust/copy.h>
#include <iostream>
#include <iterator>
int main()
{
// initialize host arrays
float h_vec_x[4] = {1.0, 1.0, 1.0, 1.0};
float h_vec_y[4] = {1.0, 2.0, 3.0, 4.0};
thrust::device_vector<float> d_vec_x(h_vec_x,h_vec_x + 4);
... | #include <thrust/device_vector.h>
#include <newton/numeric_range.hpp>
#include <newton/numeric_vector.hpp>
#include <thrust/copy.h>
#include <iostream>
#include <iterator>
int main()
{
// initialize host arrays
float h_vec_x[4] = {1.0, 1.0, 1.0, 1.0};
float h_vec_y[4] = {1.0, 2.0, 3.0, 4.0};
thrust::device_ve... | apache-2.0 | Cuda |
5c5acb4abe53d28ccd73173182c9a197c5007b4a | Test partition_point with thrust::device in __device__ code. | jaredhoberock/thrust,xiongzhanblake/thrust,mohamed-ali/thrust,andrewcorrigan/thrust-multi-permutation-iterator,raygit/thrust,zeryx/thrust,dachziegel/thrust,mohamed-ali/thrust,thrust/thrust,xiongzhanblake/thrust,arnabgho/thrust,Ricardo666666/thrust,jaredhoberock/thrust,thrust/thrust,raygit/thrust,sdalton1/thrust,marksan... | testing/backend/cuda/partition_point.cu | testing/backend/cuda/partition_point.cu | #include <unittest/unittest.h>
#include <thrust/partition.h>
#include <thrust/functional.h>
#include <thrust/execution_policy.h>
template<typename ExecutionPolicy, typename Iterator1, typename Predicate, typename Iterator2>
__global__
void partition_point_kernel(ExecutionPolicy exec, Iterator1 first, Iterator1 last, ... | #include <unittest/unittest.h>
#include <thrust/partition.h>
#include <thrust/functional.h>
#include <thrust/execution_policy.h>
template<typename Iterator1, typename Predicate, typename Iterator2>
__global__
void partition_point_kernel(Iterator1 first, Iterator1 last, Predicate pred, Iterator2 result)
{
*result = ... | apache-2.0 | Cuda |
3dd2ed3f86d612440da212d4fa62992113b88f52 | use variadic macro | cupy/cupy,cupy/cupy,cupy/cupy,cupy/cupy | cupy/_core/include/cupy/hip_workaround.cuh | cupy/_core/include/cupy/hip_workaround.cuh | #ifndef INCLUDE_GUARD_CUPY_HIP_WORKAROUND_H
#define INCLUDE_GUARD_CUPY_HIP_WORKAROUND_H
#ifdef __HIP_DEVICE_COMPILE__
// ignore mask
#define __shfl_sync(mask, ...) __shfl(__VA_ARGS__)
#define __shfl_up_sync(mask, ...) __shfl_up(__VA_ARGS__)
#define __shfl_down_sync(mask, ...) __shfl_down(__VA_ARGS__)
#define __shfl_x... | #ifndef INCLUDE_GUARD_CUPY_HIP_WORKAROUND_H
#define INCLUDE_GUARD_CUPY_HIP_WORKAROUND_H
#ifdef __HIP_DEVICE_COMPILE__
// ignore mask
#define __shfl_sync(m, x, y, z) __shfl(x, y, z)
#define __shfl_up_sync(m, x, y, z) __shfl_up(x, y, z)
#define __shfl_down_sync(m, x, y, z) __shfl_down(x, y, z)
#define __shfl_xor_sync(m... | mit | Cuda |
7945572cee3f520eb68e906ba96742451e0ff121 | Update fill_zeros_like_op.cu | pengli09/Paddle,luotao1/Paddle,yu239/Paddle,QiJune/Paddle,jacquesqiao/Paddle,hedaoyuan/Paddle,QiJune/Paddle,pkuyym/Paddle,reyoung/Paddle,yu239/Paddle,hedaoyuan/Paddle,QiJune/Paddle,jacquesqiao/Paddle,lispc/Paddle,PaddlePaddle/Paddle,PaddlePaddle/Paddle,luotao1/Paddle,hedaoyuan/Paddle,lcy-seso/Paddle,yu239/Paddle,baidu/... | paddle/operators/fill_zeros_like_op.cu | paddle/operators/fill_zeros_like_op.cu | /* Copyright (c) 2016 PaddlePaddle Authors. All Rights Reserve.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applica... | /* Copyright (c) 2016 PaddlePaddle Authors. All Rights Reserve.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applica... | apache-2.0 | Cuda |
5d7e8bfb5c022f1e5f343defd9c5bab7ac5eae0e | fix bug | lispc/Paddle,lcy-seso/Paddle,yu239/Paddle,pengli09/Paddle,luotao1/Paddle,tensor-tang/Paddle,Canpio/Paddle,hedaoyuan/Paddle,jacquesqiao/Paddle,reyoung/Paddle,yu239/Paddle,reyoung/Paddle,yu239/Paddle,QiJune/Paddle,PaddlePaddle/Paddle,hedaoyuan/Paddle,pkuyym/Paddle,baidu/Paddle,Canpio/Paddle,pkuyym/Paddle,lispc/Paddle,QiJ... | paddle/operators/fill_zeros_like_op.cu | paddle/operators/fill_zeros_like_op.cu | #define EIGEN_USE_GPU
#include "paddle/framework/op_registry.h"
#include "paddle/operators/fill_zeros_like_op.h"
REGISTER_OP_GPU_KERNEL(
fill_zeros_like,
paddle::operators::FillZerosLikeKernel<paddle::platform::GPUPlace, float>); | #include "paddle/framework/op_registry.h"
#include "paddle/operators/fill_zeros_like_op.h"
REGISTER_OP_GPU_KERNEL(
fill_zeros_like,
paddle::operators::FillZerosLikeKernel<paddle::platform::GPUPlace, float>); | apache-2.0 | Cuda |
8f946887ef55b51b09241e52d5cf4359673d084b | Fix one last test on a windows host. | apple/swift-clang,llvm-mirror/clang,apple/swift-clang,apple/swift-clang,apple/swift-clang,apple/swift-clang,apple/swift-clang,apple/swift-clang,llvm-mirror/clang,apple/swift-clang,llvm-mirror/clang,llvm-mirror/clang,llvm-mirror/clang,llvm-mirror/clang,llvm-mirror/clang,apple/swift-clang,apple/swift-clang,llvm-mirror/cl... | test/CodeGenCUDA/filter-decl.cu | test/CodeGenCUDA/filter-decl.cu | // RUN: %clang_cc1 -triple %itanium_abi_triple -emit-llvm %s -o - | FileCheck -check-prefix=CHECK-HOST %s
// RUN: %clang_cc1 -triple %itanium_abi_triple -emit-llvm %s -o - -fcuda-is-device | FileCheck -check-prefix=CHECK-DEVICE %s
#include "Inputs/cuda.h"
// This has to be at the top of the file as that's where file-... | // RUN: %clang_cc1 -triple %itanium_abi_triple -emit-llvm %s -o - | FileCheck -check-prefix=CHECK-HOST %s
// RUN: %clang_cc1 -triple %itanium_abi_triple -emit-llvm %s -o - -fcuda-is-device | FileCheck -check-prefix=CHECK-DEVICE %s
#include "Inputs/cuda.h"
// This has to be at the top of the file as that's where file-... | apache-2.0 | Cuda |
bb7f2139152d28f798622c2faba63e52e178bd72 | remove unneccessary initialization inside cuh file | GOMC-WSU/GOMC_Serial,GOMC-WSU/GOMC,GOMC-WSU/GOMC,GOMC-WSU/GOMC,GOMC-WSU/GOMC_Serial,GOMC-WSU/GOMC,GOMC-WSU/GOMC_Serial,GOMC-WSU/GOMC | src/GPU/CUDAMemoryManager.cuh | src/GPU/CUDAMemoryManager.cuh | #pragma once
#ifdef GOMC_CUDA
#include <cuda.h>
#include <cuda_runtime.h>
#include <unordered_map>
#include <iostream>
class CUDAMemoryManager {
public:
static cudaError_t mallocMemory(void **address, unsigned int size);
static cudaError_t freeMemory(void *address);
private:
static long long totalAllocatedBytes... | #pragma once
#ifdef GOMC_CUDA
#include <cuda.h>
#include <cuda_runtime.h>
#include <unordered_map>
#include <iostream>
class CUDAMemoryManager {
public:
static cudaError_t mallocMemory(void **address, unsigned int size);
static cudaError_t freeMemory(void *address);
private:
static long long totalAllocatedBytes... | mit | Cuda |
ae076b470efa18fa9cf352213467cb75b80cdf2a | Use memory fence | cupy/cupy,cupy/cupy,cupy/cupy,cupy/cupy | cupy/_core/include/cupy/hip_workaround.cuh | cupy/_core/include/cupy/hip_workaround.cuh | #ifndef INCLUDE_GUARD_CUPY_HIP_WORKAROUND_H
#define INCLUDE_GUARD_CUPY_HIP_WORKAROUND_H
#ifdef __HIP_DEVICE_COMPILE__
// ignore mask
#define __shfl_sync(mask, ...) __shfl(__VA_ARGS__)
#define __shfl_up_sync(mask, ...) __shfl_up(__VA_ARGS__)
#define __shfl_down_sync(mask, ...) __shfl_down(__VA_ARGS__)
#define __shfl_x... | #ifndef INCLUDE_GUARD_CUPY_HIP_WORKAROUND_H
#define INCLUDE_GUARD_CUPY_HIP_WORKAROUND_H
#ifdef __HIP_DEVICE_COMPILE__
// ignore mask
#define __shfl_sync(mask, ...) __shfl(__VA_ARGS__)
#define __shfl_up_sync(mask, ...) __shfl_up(__VA_ARGS__)
#define __shfl_down_sync(mask, ...) __shfl_down(__VA_ARGS__)
#define __shfl_x... | mit | Cuda |
6aeac11b0ef93b045a6a2815fe1c430f24c12ffd | increase stck size of cuda | huitseeker/libnd4j,deeplearning4j/libnd4j,deeplearning4j/libnd4j,deeplearning4j/libnd4j,deeplearning4j/libnd4j,huitseeker/libnd4j,huitseeker/libnd4j,deeplearning4j/libnd4j,deeplearning4j/libnd4j,huitseeker/libnd4j,deeplearning4j/libnd4j | test/main.cu | test/main.cu | #include <CppUTest/CommandLineTestRunner.h>
#include <pairwise_transform_tests.h>
#include <scalartests.h>
#include <transformtests.h>
#include <broadcasttests.h>
#include <shapetests.h>
#include <reducetests.h>
#include <reduce3tests.h>
#include <indexreducetests.h>
int main(int ac, char** av) {
#ifdef __CUDACC__
cu... | #include <CppUTest/CommandLineTestRunner.h>
#include <pairwise_transform_tests.h>
#include <scalartests.h>
#include <transformtests.h>
#include <broadcasttests.h>
#include <shapetests.h>
#include <reducetests.h>
#include <reduce3tests.h>
#include <indexreducetests.h>
int main(int ac, char** av) {
#ifdef __CUDACC__
cu... | apache-2.0 | Cuda |
ae9abb8947749d94d5518959cf072712a475c6f2 | Test max_element with thrust::device in __device__ code. | mohamed-ali/thrust,andrewcorrigan/thrust-multi-permutation-iterator,dachziegel/thrust,mohamed-ali/thrust,xiongzhanblake/thrust_src,marksantos/thrust,sdalton1/thrust,mohamed-ali/thrust,sarvex/thrust,egaburov/thrust,xiongzhanblake/thrust_src,arnabgho/thrust,thrust/thrust,thrust/thrust,marksantos/thrust,sdalton1/thrust,th... | testing/backend/cuda/max_element.cu | testing/backend/cuda/max_element.cu | #include <unittest/unittest.h>
#include <thrust/extrema.h>
#include <thrust/execution_policy.h>
template<typename ExecutionPolicy, typename Iterator, typename Iterator2>
__global__
void max_element_kernel(ExecutionPolicy exec, Iterator first, Iterator last, Iterator2 result)
{
*result = thrust::max_element(exec, fi... | #include <unittest/unittest.h>
#include <thrust/extrema.h>
#include <thrust/execution_policy.h>
template<typename Iterator, typename Iterator2>
__global__
void max_element_kernel(Iterator first, Iterator last, Iterator2 result)
{
*result = thrust::max_element(thrust::seq, first, last);
}
template<typename Iterato... | apache-2.0 | Cuda |
352826928bf1e9e054e7899269905ae94fdd51ea | Improve position finder. | SKA-ScienceDataProcessor/RC,SKA-ScienceDataProcessor/RC,SKA-ScienceDataProcessor/RC,SKA-ScienceDataProcessor/RC,SKA-ScienceDataProcessor/RC | MS3/Sketches/GCF_new/posFind.cu | MS3/Sketches/GCF_new/posFind.cu | #include "threadFenceReduction_kernel.cuh"
struct place {
__device__ place & operator=(const place & p) volatile {
this->pos = p.pos;
this->val = p.val;
return const_cast<place&>(*this);
}
__device__ place (unsigned p, double v) : pos(p), val(v){;}
__device__ place (const place & p) : pos(p.p... | #include "threadFenceReduction_kernel.cuh"
struct place {
__device__ place & operator=(const place & p) volatile {
this->pos = p.pos;
this->val = p.val;
return const_cast<place&>(*this);
}
__device__ place (volatile place & p) : pos(p.pos), val(p.val){;}
__device__ place (unsigned p, double v... | apache-2.0 | Cuda |
b22df8e8574d635dbdd2125b7f5c495a4cf671c1 | Use stock max function. | SKA-ScienceDataProcessor/RC,SKA-ScienceDataProcessor/RC,SKA-ScienceDataProcessor/RC,SKA-ScienceDataProcessor/RC,SKA-ScienceDataProcessor/RC | MS3/Sketches/GCF_new/dbl_max.cu | MS3/Sketches/GCF_new/dbl_max.cu | #include "threadFenceReduction_kernel.cuh"
#include <math_functions.h>
struct doubleMax {
TASKCFG double init() {return 0.0;}
TASKCFG double reduce(double x, double acc){return max(x,acc);}
TASKCFG double f(double c){return fabs(c);}
};
extern "C" __global__ void max_512_e2(const double *g_idata, double *g_oda... | #include "threadFenceReduction_kernel.cuh"
struct doubleMax {
TASKCFG double init() {return 0.0;}
TASKCFG double reduce(double x, double acc){return x > acc ? x : acc;}
TASKCFG double f(double c){return fabs(c);}
};
extern "C" __global__ void max_512_e2(const double *g_idata, double *g_odata, unsigned int n) {
... | apache-2.0 | Cuda |
bf8d293dd7888ab5de31b78ee2a920d4f07f4acb | Fix for non-resetting voltage input. | OFTNAI/Spike,OFTNAI/Spike | Spike/Backend/CUDA/Synapses/VoltageSpikingSynapses.cu | Spike/Backend/CUDA/Synapses/VoltageSpikingSynapses.cu | // -*- mode: c++ -*-
#include "Spike/Backend/CUDA/Synapses/VoltageSpikingSynapses.hpp"
SPIKE_EXPORT_BACKEND_TYPE(CUDA, VoltageSpikingSynapses);
namespace Backend {
namespace CUDA {
__device__ injection_kernel voltage_device_kernel = voltage_spiking_current_injection_kernel;
// VoltageSpikingSynapses Destru... | // -*- mode: c++ -*-
#include "Spike/Backend/CUDA/Synapses/VoltageSpikingSynapses.hpp"
SPIKE_EXPORT_BACKEND_TYPE(CUDA, VoltageSpikingSynapses);
namespace Backend {
namespace CUDA {
__device__ injection_kernel voltage_device_kernel = voltage_spiking_current_injection_kernel;
// VoltageSpikingSynapses Destru... | mit | Cuda |
00a054892b6e047599f756111206d0ee9838ae73 | Test set_difference with thrust::device in __device__ code. | zeryx/thrust,zhenglaizhang/thrust,sarvex/thrust,sdalton1/thrust,raygit/thrust,thrust/thrust,zhenglaizhang/thrust,andrewcorrigan/thrust-multi-permutation-iterator,jaredhoberock/thrust,xiongzhanblake/thrust_src,thrust/thrust,dachziegel/thrust,marksantos/thrust,xiongzhanblake/thrust,jaredhoberock/thrust,marksantos/thrust,... | testing/backend/cuda/set_difference.cu | testing/backend/cuda/set_difference.cu | #include <unittest/unittest.h>
#include <thrust/set_operations.h>
#include <thrust/execution_policy.h>
template<typename ExecutionPolicy, typename Iterator1, typename Iterator2, typename Iterator3, typename Iterator4>
__global__
void set_difference_kernel(ExecutionPolicy exec, Iterator1 first1, Iterator1 last1, Itera... | #include <unittest/unittest.h>
#include <thrust/set_operations.h>
#include <thrust/execution_policy.h>
template<typename Iterator1, typename Iterator2, typename Iterator3, typename Iterator4>
__global__
void set_difference_kernel(Iterator1 first1, Iterator1 last1, Iterator2 first2, Iterator2 last2, Iterator3 result1,... | apache-2.0 | Cuda |
4f38c2ff5c7cddee29ad1f3119dfef3bf9485da2 | remove deadcode | hughperkins/cuda-on-cl,hughperkins/coriander,hughperkins/cuda-on-cl,hughperkins/cuda-on-cl,hughperkins/coriander,hughperkins/coriander,hughperkins/cuda-on-cl,hughperkins/coriander | test/test_memhostalloc.cu | test/test_memhostalloc.cu | // tests cuMemHostAlloc
#include <iostream>
#include <memory>
using namespace std;
#include <cuda.h>
__global__ void incrValue(float *data, int idx, float value) {
if(threadIdx.x == 0) {
data[idx] += value;
}
}
int main(int argc, char *argv[]) {
int N = 1024;
float *floats;
cuMemHostAl... | // tests cuMemHostAlloc
#include <iostream>
#include <memory>
using namespace std;
#include <cuda.h>
// __global__ void setValue(float *data, int idx, float value) {
// if(threadIdx.x == 0) {
// data[idx] = value;
// }
// }
__global__ void incrValue(float *data, int idx, float value) {
if(threa... | apache-2.0 | Cuda |
1a0cbf756c8edd5055b4422b08ab088abe1b2c42 | Fix in line with previous changed | gift-surg/SlicSeg,gift-surg/SlicSeg,gift-surg/SlicSeg | matlab/library/FeatureExtract/imageHoG.cu | matlab/library/FeatureExtract/imageHoG.cu | __device__ double getPixel(const double *array,int H,int W,int i,int j)
{
if(i<0 || i>=H || j<0 ||j>=W)
{
return 0;
}
else
{
return *(array+H*j+i);
}
}
__device__ void setPixel(double *array,int H,int W,int i,int j,double value)
{
if(i<0 || i>=H || j<0 ||j>=W)
{
r... | __device__ double getPixel(const double *array,int H,int W,int i,int j)
{
if(i<0 || i>=H || j<0 ||j>=W)
{
return 0;
}
else
{
return *(array+H*j+i);
}
}
__device__ void setPixel(double *array,int H,int W,int i,int j,double value)
{
if(i<0 || i>=H || j<0 ||j>=W)
{
r... | bsd-3-clause | Cuda |
99aa2c9f281073cf862cd2212512b4441ab19098 | test update | ccecka/FLENS,ccecka/FLENS,ccecka/FLENS,ccecka/FLENS | test_cusolver.cu | test_cusolver.cu | // $ nvcc -std=c++11 -ccbin=g++-4.7 -I. -o test_cusolver test_cusolver.cu -lcublas -lcusolver
#include <iostream>
#include <complex>
#include <thrust/device_malloc_allocator.h>
#define WITH_CUBLAS
#define WITH_CUSOLVER
#define CXXBLAS_DEBUG
#define CXXLAPACK_DEBUG
#define ALWAYS_USE_CXXLAPACK
#include "flens/flens.... | // $ nvcc -std=c++11 -ccbin=g++-4.7 -I. -o test_cusolver test_cusolver.cu -lcublas -lcusolver
#include <iostream>
#include <complex>
#include <thrust/device_malloc_allocator.h>
#define WITH_CUBLAS
#define WITH_CUSOLVER
#define CXXBLAS_DEBUG
#define CXXLAPACK_DEBUG
#define ALWAYS_USE_CXXLAPACK
#include "flens/flens.... | bsd-3-clause | Cuda |
9680ffd8426e630f025925a16d51e5010a270cbf | Fix rocm build caused by #12699 (#12787) | microsoft/onnxruntime,microsoft/onnxruntime,microsoft/onnxruntime,microsoft/onnxruntime,microsoft/onnxruntime,microsoft/onnxruntime,microsoft/onnxruntime,microsoft/onnxruntime,microsoft/onnxruntime,microsoft/onnxruntime,microsoft/onnxruntime,microsoft/onnxruntime | onnxruntime/contrib_ops/rocm/bert/fast_gelu_impl.cu | onnxruntime/contrib_ops/rocm/bert/fast_gelu_impl.cu | /*
The implementation of this file is based on gelu plugin in TensorRT demo:
https://github.com/NVIDIA/TensorRT/tree/release/5.1/demo/BERT/
Copyright 2019 NVIDIA Corporation
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtai... | /*
The implementation of this file is based on gelu plugin in TensorRT demo:
https://github.com/NVIDIA/TensorRT/tree/release/5.1/demo/BERT/
Copyright 2019 NVIDIA Corporation
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtai... | mit | Cuda |
ff1bfdedc97eb0834745e812abd619581fde7950 | Fix CRLF in sum_op.cu | pengli09/Paddle,pkuyym/Paddle,pengli09/Paddle,luotao1/Paddle,pkuyym/Paddle,pengli09/Paddle,jacquesqiao/Paddle,pkuyym/Paddle,tensor-tang/Paddle,reyoung/Paddle,QiJune/Paddle,QiJune/Paddle,QiJune/Paddle,reyoung/Paddle,Canpio/Paddle,reyoung/Paddle,reyoung/Paddle,tensor-tang/Paddle,lcy-seso/Paddle,putcn/Paddle,luotao1/Paddl... | paddle/operators/sum_op.cu | paddle/operators/sum_op.cu | /* Copyright (c) 2016 PaddlePaddle Authors. All Rights Reserve.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed ... | /* Copyright (c) 2016 PaddlePaddle Authors. All Rights Reserve.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed ... | apache-2.0 | Cuda |
3c4117106f2bd4f86fd7ab770fb4fba45a91f692 | Add unittest | Canpio/Paddle,lcy-seso/Paddle,reyoung/Paddle,Canpio/Paddle,luotao1/Paddle,tensor-tang/Paddle,chengduoZH/Paddle,jacquesqiao/Paddle,chengduoZH/Paddle,putcn/Paddle,reyoung/Paddle,Canpio/Paddle,baidu/Paddle,putcn/Paddle,reyoung/Paddle,PaddlePaddle/Paddle,luotao1/Paddle,QiJune/Paddle,putcn/Paddle,pkuyym/Paddle,tensor-tang/P... | paddle/framework/mixed_vector_test.cu | paddle/framework/mixed_vector_test.cu | /* Copyright (c) 2016 PaddlePaddle Authors. All Rights Reserve.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applica... | /* Copyright (c) 2016 PaddlePaddle Authors. All Rights Reserve.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applica... | apache-2.0 | Cuda |
31be13c29f5716c937d6446c973c9a9274afecad | Mark the debug.cu tests as KNOWN_FAILURES on OSX | julianromera/thrust,levendlee/thrust,allendaicool/thrust,julianromera/thrust,Vishwa07/thrust,levendlee/thrust,malenie/thrust,lishi0927/thrust,julianromera/thrust,hemmingway/thrust,bfurtaw/thrust,Vishwa07/thrust,bfurtaw/thrust,h1arshad/thrust,hemmingway/thrust,Vishwa07/thrust,google-code-export/thrust,allendaicool/thrus... | testing/debug.cu | testing/debug.cu | #define THRUST_DEBUG 1
#include <unittest/unittest.h>
#include <thrust/device_ptr.h>
#include <thrust/transform.h>
#include <thrust/reduce.h>
#include <thrust/scan.h>
#include <thrust/sort.h>
#include <thrust/system_error.h>
#if THRUST_DEVICE_BACKEND == THRUST_DEVICE_BACKEND_CUDA
void TestTransformNullPtr(void)
{
#i... | #define THRUST_DEBUG 1
#include <unittest/unittest.h>
#include <thrust/device_ptr.h>
#include <thrust/transform.h>
#include <thrust/reduce.h>
#include <thrust/scan.h>
#include <thrust/sort.h>
#include <thrust/system_error.h>
#if THRUST_DEVICE_BACKEND == THRUST_DEVICE_BACKEND_CUDA
void TestTransformNullPtr(void)
{
... | apache-2.0 | Cuda |
8929bf9a87d0e2a93979f63c71ce28d440972f89 | Fix following error | keisuke-umezawa/chainer,pfnet/chainer,chainer/chainer,ktnyt/chainer,chainer/chainer,ktnyt/chainer,jnishi/chainer,ktnyt/chainer,wkentaro/chainer,chainer/chainer,wkentaro/chainer,hvy/chainer,niboshi/chainer,jnishi/chainer,niboshi/chainer,keisuke-umezawa/chainer,ktnyt/chainer,okuta/chainer,chainer/chainer,wkentaro/chainer... | chainerx/chainerx/cuda/cuda_device/misc.cu | chainerx/chainerx/cuda/cuda_device/misc.cu | #include "chainerx/cuda/cuda_device.h"
#include <cmath>
#include <cstdint>
#include <cuda_runtime.h>
#include "chainerx/array.h"
#include "chainerx/cuda/cuda_runtime.h"
#include "chainerx/cuda/elementwise.cuh"
#include "chainerx/device.h"
#include "chainerx/dtype.h"
namespace chainerx {
namespace cuda {
namespace {... | #include "chainerx/cuda/cuda_device.h"
#include <cmath>
#include <cstdint>
#include <cuda_runtime.h>
#include "chainerx/array.h"
#include "chainerx/cuda/cuda_runtime.h"
#include "chainerx/cuda/elementwise.cuh"
#include "chainerx/device.h"
#include "chainerx/dtype.h"
namespace chainerx {
namespace cuda {
namespace {... | mit | Cuda |
9a8eefeeec42a409ddf05d828ba9ac8eed60f6bb | Update gunrock_mad.cu | anshumang/gunrock-swched-swmm,vvishal/gunrock,anshumang/gunrockINST,anshumang/gunrockINST,anshumang/gunrockINST,vvishal/gunrock,anshumang/gunrock-swched-swmm,Damien-/gunrock,anshumang/gunrock-swched-swmm,anshumang/gunrockINST,Damien-/gunrock,vvishal/gunrock,ydwu/gunrock,ydwu/gunrock,anshumang/gunrock-swched-swmm,ydwu/g... | wrapper/test/gunrock_mad.cu | wrapper/test/gunrock_mad.cu | /**
* @file gunrock_mad.cu
* @brief mad calculation procedure
*
*/
#include <wrapper/app/mad/mad_enactor.cuh>
#include <wrapper/app/mad/mad_functor.cuh>
#include <wrapper/app/mad/mad_problem.cuh>
#include <wrapper/util/util.cuh>
using namespace wrapper::app::mad;
#ifdef __cplusplus
extern "C"
{
#endif
void ... | /**
* @file gunrock_mad.cu
* @brief mad calculation procedure
*
*/
#include <wrapper/app/mad/mad_enactor.cuh>
#include <wrapper/app/mad/mad_functor.cuh>
#include <wrapper/app/mad/mad_problem.cuh>
#include <wrapper/util/util.cuh>
#ifdef __cplusplus
extern "C"
{
#endif
void gunrock_mad_int(int *origin_element... | apache-2.0 | Cuda |
bd3eb82acb6a3e4985266e055d4adf2922cd8321 | support for multi vector optimized | ssomesh/SALLOC | driver_phase3.cu | driver_phase3.cu | // This is the driver program for SALLOC
#include <stdio.h>
#include <cuda.h>
#include "salloc_phase3.h"
#define CHUNK_SZ 32 // size of a chunk
#define CAP 16 // number of chunks in the chunk
typedef int T1; //
__global__ void kernel(GPUArena<CHUNK_SZ,T1> a )
{
a.get_new_chunk();
}
__global__ void kernel1(GPUA... | // This is the driver program for SALLOC
#include <stdio.h>
#include <cuda.h>
#include "salloc_phase3.h"
#define CHUNK_SZ 32 // size of a chunk
#define CAP 16 // number of chunks in the chunk
typedef int T1; //
__global__ void kernel1(GPUArena<CHUNK_SZ,T1> a, GPUChunk<CHUNK_SZ,T1>* v)
{
printf("%p\n",v);
}
__g... | apache-2.0 | Cuda |
458f1d82a8738c877c80c011644bbbeaa200b750 | Test for_each & for_each_n with thrust::seq in __device__ code. | zhenglaizhang/thrust,marksantos/thrust,egaburov/thrust,thrust/thrust,xiongzhanblake/thrust,zhenglaizhang/thrust,xiongzhanblake/thrust_src,raygit/thrust,marksantos/thrust,raygit/thrust,jaredhoberock/thrust,sarvex/thrust,sdalton1/thrust,xiongzhanblake/thrust,zeryx/thrust,jaredhoberock/thrust,marksantos/thrust,andrewcorri... | testing/backend/cuda/for_each.cu | testing/backend/cuda/for_each.cu | #include <unittest/unittest.h>
#include <thrust/for_each.h>
#include <thrust/execution_policy.h>
static const size_t NUM_REGISTERS = 100;
template <size_t N> __host__ __device__ void f (int * x) { int temp = *x; f<N - 1>(x + 1); *x = temp;};
template <> __host__ __device__ void f<0>(int * x) { }
template <s... | #include <unittest/unittest.h>
#include <thrust/for_each.h>
static const size_t NUM_REGISTERS = 100;
template <size_t N> __host__ __device__ void f (int * x) { int temp = *x; f<N - 1>(x + 1); *x = temp;};
template <> __host__ __device__ void f<0>(int * x) { }
template <size_t N>
struct CopyFunctorWithManyRe... | apache-2.0 | Cuda |
681f8404a825870959223a25496ae3d9b8a1e93d | fix Backward_gpu function signature in molgrid_data_layer.cu | gnina/gnina,gnina/gnina,gnina/gnina,gnina/gnina,gnina/gnina,gnina/gnina | src/caffe/layers/molgrid_data_layer.cu | src/caffe/layers/molgrid_data_layer.cu | #include <stdint.h>
#include <vector>
#include "caffe/layers/molgrid_data_layer.hpp"
//gridding is implemented in gridmaker
#include "gninasrc/lib/gridmaker.cu"
namespace caffe {
template <typename Dtype>
void MolGridDataLayer<Dtype>::Forward_gpu(const vector<Blob<Dtype>*>& bottom,
const vector<Blob<Dtype>*>& t... | #include <stdint.h>
#include <vector>
#include "caffe/layers/molgrid_data_layer.hpp"
//gridding is implemented in gridmaker
#include "gninasrc/lib/gridmaker.cu"
namespace caffe {
template <typename Dtype>
void MolGridDataLayer<Dtype>::Forward_gpu(const vector<Blob<Dtype>*>& bottom,
const vector<Blob<Dtype>*>& t... | apache-2.0 | Cuda |
74f6cf4f1180ae2a1e4b74266842d9b43c607d61 | Add forgotten sort to Halide API. | SKA-ScienceDataProcessor/RC,SKA-ScienceDataProcessor/RC,SKA-ScienceDataProcessor/RC,SKA-ScienceDataProcessor/RC,SKA-ScienceDataProcessor/RC | MS6/kernel/nvidia/gridder/halide_api.cu | MS6/kernel/nvidia/gridder/halide_api.cu | #include "grid_gpu.cuh"
#include "halide_buf.h"
extern "C"
EXPORT
int nvGridder(const double _scale, const int32_t _grid_size, buffer_t *_vis_buffer, buffer_t *_gcf_buffer, buffer_t *_uvg_buffer){
#define visptr reinterpret_cast<combined*>(_vis_buffer->host)
#define visnum _vis_buffer->extent[1]
bin_sort5(visptr... | #include "grid_gpu.cuh"
#include "halide_buf.h"
extern "C"
int nvGridder(const double _scale, const int32_t _grid_size, buffer_t *_vis_buffer, buffer_t *_gcf_buffer, buffer_t *_uvg_buffer){
// FIXME: make gridGPUx respect buffers locations, i.e.
// to check if they already are on GPU and skip allocation and marsha... | apache-2.0 | Cuda |
3c3b752cb654aab0416ef8694386db667d45bcfc | Use the newer connection oriented update_potential call | schatten/moment,schatten/moment,schatten/moment | test/neuron-test.cu | test/neuron-test.cu | /* Test neuron functionality */
#include <stdio.h>
// Note that we are including the source file and not the header file only.
// This allows us access to static variables and globals (gasp!). This is more
// or less a close replica of the exposure that the functions being tested will
// get.
#include "neuron.cu"
#in... | /* Test neuron functionality */
#include <stdio.h>
// Note that we are including the source file and not the header file only.
// This allows us access to static variables and globals (gasp!). This is more
// or less a close replica of the exposure that the functions being tested will
// get.
#include "neuron.cu"
#in... | mit | Cuda |
e91cc7466acedc73310076c49728c23cf4e530f7 | Remove __host__ from functor. | egaburov/agency,egaburov/agency | test_concurrent.cu | test_concurrent.cu | #include <iostream>
#include <agency/execution_policy.hpp>
#include <agency/cuda/execution_policy.hpp>
struct functor
{
__device__
void operator()(agency::cuda::concurrent_agent& self)
{
printf("agent %d arriving at barrier\n", (int)self.index());
self.wait();
printf("departing barrier\n");
}
};
... | #include <iostream>
#include <agency/execution_policy.hpp>
#include <agency/cuda/execution_policy.hpp>
struct functor
{
__host__ __device__
void operator()(agency::cuda::concurrent_agent& self)
{
printf("agent %d arriving at barrier\n", (int)self.index());
self.wait();
printf("departing barrier\n")... | bsd-3-clause | Cuda |
008c3b0c22bbc93340e55947e82c811fe3ea995b | fix Backward_gpu function signature in molgrid_data_layer.cu | gnina/gnina,gnina/gnina,gnina/gnina,gnina/gnina,gnina/gnina,gnina/gnina | caffe/src/caffe/layers/molgrid_data_layer.cu | caffe/src/caffe/layers/molgrid_data_layer.cu | #include <stdint.h>
#include <vector>
#include "caffe/layers/molgrid_data_layer.hpp"
//gridding is implemented in gridmaker
#include "gninasrc/lib/gridmaker.cu"
namespace caffe {
template <typename Dtype>
void MolGridDataLayer<Dtype>::Forward_gpu(const vector<Blob<Dtype>*>& bottom,
const vector<Blob<Dtype>*>& t... | #include <stdint.h>
#include <vector>
#include "caffe/layers/molgrid_data_layer.hpp"
//gridding is implemented in gridmaker
#include "gninasrc/lib/gridmaker.cu"
namespace caffe {
template <typename Dtype>
void MolGridDataLayer<Dtype>::Forward_gpu(const vector<Blob<Dtype>*>& bottom,
const vector<Blob<Dtype>*>& t... | apache-2.0 | Cuda |
30706241157fb29b04b3e6d41d02be894089e7c0 | Test is_sorted_until with thrust::device in __device__ code. | zhenglaizhang/thrust,sdalton1/thrust,xiongzhanblake/thrust_src,zhenglaizhang/thrust,marksantos/thrust,jaredhoberock/thrust,jaredhoberock/thrust,raygit/thrust,arnabgho/thrust,thrust/thrust,andrewcorrigan/thrust-multi-permutation-iterator,xiongzhanblake/thrust,dachziegel/thrust,zeryx/thrust,raygit/thrust,GrimDerp/thrust,... | testing/backend/cuda/is_sorted_until.cu | testing/backend/cuda/is_sorted_until.cu | #include <unittest/unittest.h>
#include <thrust/sort.h>
#include <thrust/execution_policy.h>
template<typename ExecutionPolicy, typename Iterator1, typename Iterator2>
__global__
void is_sorted_until_kernel(ExecutionPolicy exec, Iterator1 first, Iterator1 last, Iterator2 result)
{
*result = thrust::is_sorted_until(... | #include <unittest/unittest.h>
#include <thrust/sort.h>
#include <thrust/execution_policy.h>
template<typename Iterator1, typename Iterator2>
__global__
void is_sorted_until_kernel(Iterator1 first, Iterator1 last, Iterator2 result)
{
*result = thrust::is_sorted_until(thrust::seq, first, last);
}
template<typename... | apache-2.0 | Cuda |
d625b8e3167e3489cf6405b1fe7fd2061150de93 | Add test census_transform code for pitch | fixstars/libSGM,fixstars-jp/libSGM | test/census_transform_test.cu | test/census_transform_test.cu | #include <gtest/gtest.h>
#include "census_transform.hpp"
#include "generator.hpp"
#include "test_utility.hpp"
#include "debug.hpp"
namespace {
template <typename T>
thrust::host_vector<sgm::feature_type> census_transform(
const thrust::host_vector<T>& src, size_t width, size_t height, size_t pitch)
{
const int hor... | #include <gtest/gtest.h>
#include "census_transform.hpp"
#include "generator.hpp"
#include "test_utility.hpp"
#include "debug.hpp"
namespace {
template <typename T>
thrust::host_vector<sgm::feature_type> census_transform(
const thrust::host_vector<T>& src, size_t width, size_t height)
{
const int hor = 9 / 2, ver ... | apache-2.0 | Cuda |
2909fd3ae18250c9588edaeaef846e27913eb9dd | include limits for linux numeric_limits | poparteu/popsift,alicevision/popsift,poparteu/popsift,alicevision/popsift,alicevision/popsift | popsift/common/write_plane_2d.cu | popsift/common/write_plane_2d.cu | #include "write_plane_2d.h"
#include <iostream>
#include <fstream>
#include <limits>
// #include "debug_macros.h"
// #include "align_macro.h"
// #include "assist.h"
// #include <stdio.h>
// #include <assert.h>
using namespace std;
namespace popart {
__host__
void write_plane2D( const char* filename, bool onDevice,... | #include "write_plane_2d.h"
#include <iostream>
#include <fstream>
// #include "debug_macros.h"
// #include "align_macro.h"
// #include "assist.h"
// #include <stdio.h>
// #include <assert.h>
using namespace std;
namespace popart {
void write_plane2D( const char* filename, bool onDevice, Plane2D_float& f )
{
i... | mpl-2.0 | Cuda |
52171d126e22d1dbfe352659edffe8647ac9df68 | Add is_numeric() and Timer class | ACSAlab/olive,ACSAlab/olive | src/olive_util.cu | src/olive_util.cu | /**
* Utils
*
* Author: Yichao Cheng (onesuperclark@gmail.com)
* Created on: 2014-10-20
* Last Modified: 2014-10-23
*/
#include "olive_def.h"
#include "olive_util.h"
int get_num_gpus(void) {
int num = 1;
SAFE_CALL(cudaGetDeviceCount(&num));
return num;
}
void set_gpu_num(int num) {
SAFE_CALL(... | /**
* Utils
*
* Author: Yichao Cheng (onesuperclark@gmail.com)
* Created on: 2014-10-20
* Last Modified: 2014-10-23
*/
#include "olive_def.h"
#include "olive_util.h"
int get_num_gpus(void) {
int num = 1;
SAFE_CALL(cudaGetDeviceCount(&num));
return num;
}
void set_gpu_num(int num) {
SAFE_CALL(... | mit | Cuda |
e3761f78985a2baadb703d01ad4f8a82928769f1 | Add some more executors to test | egaburov/agency,egaburov/agency | test_is_executor.cu | test_is_executor.cu | #include <agency/cuda/grid_executor.hpp>
#include <agency/cuda/block_executor.hpp>
#include <agency/flattened_executor.hpp>
#include <agency/cuda/parallel_executor.hpp>
#include <agency/cuda/concurrent_executor.hpp>
#include <agency/nested_executor.hpp>
#include <agency/concurrent_executor.hpp>
#include <agency/sequent... | #include <agency/cuda/grid_executor.hpp>
#include <agency/cuda/parallel_executor.hpp>
#include <agency/cuda/concurrent_executor.hpp>
#include <agency/nested_executor.hpp>
#include <agency/concurrent_executor.hpp>
#include <agency/sequential_executor.hpp>
#include <agency/executor_traits.hpp>
#include <iostream>
int ma... | bsd-3-clause | Cuda |
137dc3e3d5a60dbf1e77bb20aa0cfc51388e1cf0 | add fp16 kernel to clip_grad (#41661) | luotao1/Paddle,luotao1/Paddle,PaddlePaddle/Paddle,luotao1/Paddle,luotao1/Paddle,luotao1/Paddle,PaddlePaddle/Paddle,PaddlePaddle/Paddle,luotao1/Paddle,PaddlePaddle/Paddle,PaddlePaddle/Paddle,luotao1/Paddle,PaddlePaddle/Paddle,PaddlePaddle/Paddle | paddle/phi/kernels/gpu/clip_grad_kernel.cu | paddle/phi/kernels/gpu/clip_grad_kernel.cu | // Copyright (c) 2022 PaddlePaddle Authors. All Rights Reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required... | // Copyright (c) 2022 PaddlePaddle Authors. All Rights Reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required... | apache-2.0 | Cuda |
5cfd1de4d7a1f23acec170aec1ff74882c31f0b1 | read only feature did not work, but made writeparameterfile function output .info instead of .cfg | hfan36/recon | CT_Recon/mlem.cu | CT_Recon/mlem.cu | #include <iostream>
#include <iomanip>
#include <string>
#include <sstream>
#include <Windows.h>
#include <tchar.h>
#include <stdio.h>
#include <strsafe.h>
#include <cuda_profiler_api.h>
#include "hf_siddon_recon.hpp"
//maybe I should include how long it took to run the program in the parameter file???
//call it .info... | #include <iostream>
#include <iomanip>
#include <string>
#include <sstream>
#include <Windows.h>
#include <tchar.h>
#include <stdio.h>
#include <strsafe.h>
#include <cuda_profiler_api.h>
#include "hf_siddon_recon.hpp"
//maybe I should include how long it took to run the program in the parameter file???
//call it .info... | mit | Cuda |
8796cf9f12739e526e21c6bca48b8ed79fbe905b | Fix dtranspose_front | wichtounet/etl-gpu-blas,wichtounet/etl-gpu-blas | src/transpose_front.cu | src/transpose_front.cu | //=======================================================================
// Copyright (c) 2017 Baptiste Wicht
// Distributed under the terms of the MIT License.
// (See accompanying file LICENSE or copy at
// http://opensource.org/licenses/MIT)
//=======================================================================... | //=======================================================================
// Copyright (c) 2017 Baptiste Wicht
// Distributed under the terms of the MIT License.
// (See accompanying file LICENSE or copy at
// http://opensource.org/licenses/MIT)
//=======================================================================... | mit | Cuda |
69c7f9964f91650aacc785e4c57b57a6057a4da6 | Remove superfluous semi-colon | schatten/moment,schatten/moment,schatten/moment | test/neuron-test.cu | test/neuron-test.cu | /* Test neuron functionality */
#include <stdio.h>
// Note that we are including the source file and not the header file only.
// This allows us access to static variables and globals (gasp!). This is more
// or less a close replica of the exposure that the functions being tested will
// get.
#include "neuron.cu"
#in... | /* Test neuron functionality */
#include <stdio.h>
// Note that we are including the source file and not the header file only.
// This allows us access to static variables and globals (gasp!). This is more
// or less a close replica of the exposure that the functions being tested will
// get.
#include "neuron.cu"
#in... | mit | Cuda |
e6a8bdbf4d5ab15de946b190b868b56e90acbce5 | Fix typo in tuple_scan.cu | bfurtaw/thrust,google-code-export/thrust,lishi0927/thrust,rdmenezes/thrust,julianromera/thrust,malenie/thrust,UIKit0/thrust,hemmingway/thrust,lishi0927/thrust,allendaicool/thrust,h1arshad/thrust,rdmenezes/thrust,lishi0927/thrust,bfurtaw/thrust,Vishwa07/thrust,h1arshad/thrust,h1arshad/thrust,UIKit0/thrust,malenie/thrust... | testing/tuple_scan.cu | testing/tuple_scan.cu | #include <unittest/unittest.h>
#include <thrust/tuple.h>
#include <thrust/scan.h>
#include <thrust/transform.h>
using namespace unittest;
using namespace thrust;
template <typename Tuple>
__host__ __device__
Tuple operator+(const Tuple &lhs, const Tuple &rhs)
{
return make_tuple(get<0>(lhs) + get<0>(rhs),
... | #include <unittest/unittest.h>
#include <thrust/tuple.h>
#include <thrust/scan.h>
#include <thrust/transform.h>
using namespace unittest;
using namespace thrust;
template <typename Tuple>
__host__ __device__
Tuple operator+(const Tuple &lhs, const Tuple &rhs)
{
return make_tuple(get<0>(lhs) + get<0>(rhs),
... | apache-2.0 | Cuda |
c41b6c53257a23e4a6e1138bd78d005cee3080dc | Add a test for the associated shared_future type | egaburov/agency,egaburov/agency | test_uber_future.cu | test_uber_future.cu | #include <cassert>
#include "uber_future.hpp"
#include <iostream>
struct continuation_1
{
__host__ __device__
int operator()(int& arg)
{
return arg + 7;
}
};
struct continuation_2
{
__host__ __device__
int operator()(int& arg)
{
return arg + 42;
};
};
int main()
{
static_assert(agency::deta... | #include <cassert>
#include "uber_future.hpp"
#include <iostream>
struct continuation_1
{
__host__ __device__
int operator()(int& arg)
{
return arg + 7;
}
};
struct continuation_2
{
__host__ __device__
int operator()(int& arg)
{
return arg + 42;
};
};
int main()
{
static_assert(agency::deta... | bsd-3-clause | Cuda |
bb92e4542d41d8626004b933feb6298d63e82b65 | Update Doxygen documentation with conventions | barbagroup/cuIBM,barbagroup/cuIBM,barbagroup/cuIBM | src/cuIBM.cu | src/cuIBM.cu | /***************************************************************************//**
* \mainpage cuIBM
*
* A GPU-based Immersed Boundary Method
*
* \author Anush Krishnan (anush@bu.edu)
*/
/***************************************************************************//**
* \file cuIBM.cu
* \author Anush Krishnan (a... | /***************************************************************************//**
* \mainpage cuIBM
*
* A GPU-based Immersed Boundary Method
*
* \author Krishnan, A. (anush@bu.edu)
*/
/***************************************************************************//**
* \file cuIBM.cu
* \author Krishnan, A. (anush@bu.edu)... | mit | Cuda |
8ca3a0ca80293baa3af205db69a8eeee8dd736be | Fix faulty test from rL288448 | apple/swift-clang,llvm-mirror/clang,llvm-mirror/clang,apple/swift-clang,apple/swift-clang,llvm-mirror/clang,llvm-mirror/clang,apple/swift-clang,llvm-mirror/clang,apple/swift-clang,apple/swift-clang,apple/swift-clang,llvm-mirror/clang,llvm-mirror/clang,apple/swift-clang,llvm-mirror/clang,llvm-mirror/clang,llvm-mirror/cl... | test/Driver/cuda-no-sanitizers.cu | test/Driver/cuda-no-sanitizers.cu | // Check that -fsanitize=foo doesn't get passed down to device-side
// compilation.
//
// REQUIRES: clang-driver
//
// RUN: %clang -### -target x86_64-linux-gnu -c --cuda-gpu-arch=sm_20 -fsanitize=address %s 2>&1 | \
// RUN: FileCheck %s
// CHECK-NOT: error: unsupported option '-fsanitize=address'
// CHECK-DAG: "-fc... | // Check that -fsanitize=foo doesn't get passed down to device-side
// compilation.
//
// REQUIRES: clang-driver
//
// RUN: %clang -### -target x86_64-linux-gnu -c --cuda-gpu-arch=sm_20 -fsanitize=address %s 2>&1 | \
// RUN: FileCheck %s
// CHECK-NOT: error:
// CHECK-DAG: "-fcuda-is-device"
// CHECK-NOT: "-fsanitize... | apache-2.0 | Cuda |
3d3ccbcc3e284138046c8089bbe4eb63a38ecfd4 | test the kernel-call context | uajain/gtksourceview,GNOME/gtksourceview,GNOME/gtksourceview,GNOME/gtksourceview,uajain/gtksourceview,GNOME/gtksourceview,uajain/gtksourceview,cburschka/gtksourceview,cburschka/gtksourceview,GNOME/gtksourceview,cburschka/gtksourceview,GNOME/gtksourceview,uajain/gtksourceview,cburschka/gtksourceview,cburschka/gtksourcev... | tests/syntax-highlighting/file.cu | tests/syntax-highlighting/file.cu | #include "cuMatrix.h"
__global__ void make_BlackWhite(int *image, int N){
unsigned int x = blockIdx.x * blockDim.x + threadIdx.x;
unsigned int y = blockIdx.y * blockDim.y + threadIdx.y;
image[y*N + x] = image[y*N + x] > 128 ? 255 : 0;
}
void convertToArray(int **matrix, int *array, int N){
for(unsigned int i=0; ... | #include "cuMatrix.h"
__global__ void make_BlackWhite(int *image, int N){
unsigned int x = blockIdx.x * blockDim.x + threadIdx.x;
unsigned int y = blockIdx.y * blockDim.y + threadIdx.y;
image[y*N + x] = image[y*N + x] > 128 ? 255 : 0;
}
void convertToArray(int **matrix, int *array, int N){
for(unsigned int i=0; ... | lgpl-2.1 | Cuda |
8627ee4d7ec1bf6a024f5247974d74708b009d25 | Add <cmath> to monte_carlo.cu. fixes issue 383 | UIKit0/thrust,allendaicool/thrust,rdmenezes/thrust,Vishwa07/thrust,malenie/thrust,allendaicool/thrust,UIKit0/thrust,bfurtaw/thrust,lishi0927/thrust,malenie/thrust,levendlee/thrust,google-code-export/thrust,lishi0927/thrust,rdmenezes/thrust,hemmingway/thrust,bfurtaw/thrust,bfurtaw/thrust,levendlee/thrust,bfurtaw/thrust,... | examples/monte_carlo.cu | examples/monte_carlo.cu | #include <thrust/random.h>
#include <thrust/iterator/counting_iterator.h>
#include <thrust/functional.h>
#include <thrust/transform_reduce.h>
#include <iostream>
#include <iomanip>
#include <cmath>
// we could vary M & N to find the perf sweet spot
__host__ __device__
unsigned int hash(unsigned int a)
{
a = (a+0... | #include <thrust/random.h>
#include <thrust/iterator/counting_iterator.h>
#include <thrust/functional.h>
#include <thrust/transform_reduce.h>
#include <iostream>
#include <iomanip>
// we could vary M & N to find the perf sweet spot
__host__ __device__
unsigned int hash(unsigned int a)
{
a = (a+0x7ed55d16) + (a<<... | apache-2.0 | Cuda |
82d6812ad8ca67f9e502973e6952199008b5beda | Remove now-unused kernels from header file | stanfordnlp/spinn,nyu-mll/spinn,stanfordnlp/spinn,nyu-mll/spinn,stanfordnlp/spinn,nyu-mll/spinn | metal_stack/kernels.cuh | metal_stack/kernels.cuh | #ifndef _kernels_
#define _kernels_
#include <cstdlib>
#include <cuda_runtime.h>
namespace kernels {
/**
* Add two vectors inplace (writing to the first).
*
* v1 = v1 * v1_coeff + v2 * v2_coeff
*/
__global__ void addi_vv(float *v1, const float *v2,
float v1_coeff, float v2_coeff);
... | #ifndef _kernels_
#define _kernels_
#include <cstdlib>
#include <cuda_runtime.h>
namespace kernels {
/**
* Broadcast-add a scalar and a vector of dimension `N`.
*
* dst = src_s + src_v_coeff * src_v
*/
__global__ void add_sv(float *dst, float src_s, float src_v_coeff,
const float *src... | mit | Cuda |
7e3833a7ab419ae2f89e2b70577ef8e07d5b00e3 | update license, test=document_fix (#44144) | PaddlePaddle/Paddle,PaddlePaddle/Paddle,luotao1/Paddle,PaddlePaddle/Paddle,PaddlePaddle/Paddle,luotao1/Paddle,luotao1/Paddle,PaddlePaddle/Paddle,luotao1/Paddle,PaddlePaddle/Paddle,luotao1/Paddle,PaddlePaddle/Paddle,luotao1/Paddle,luotao1/Paddle | paddle/fluid/platform/device_context_test_cuda_graph.cu | paddle/fluid/platform/device_context_test_cuda_graph.cu | /* Copyright (c) 2022 PaddlePaddle Authors. All Rights Reserved.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or... | /* Copyright (c) 2016 PaddlePaddle Authors. All Rights Reserved.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or... | apache-2.0 | Cuda |
a66708a0c4adff6ea28b9619bd0361aab07f8e6e | Add a larger test case for the when_all() test | egaburov/agency,egaburov/agency | testing/cuda/test_when_all.cu | testing/cuda/test_when_all.cu | #include <agency/cuda/future.hpp>
#include <cassert>
int main()
{
{ // int, int -> (int, int, int)
auto f1 = agency::cuda::make_ready_future<int>(7);
auto f2 = agency::cuda::make_ready_future<int>(13);
auto f3 = agency::cuda::make_ready_future<int>(42);
auto f4 = agency::cuda::when_all(f1, f2, f3);
... | #include <agency/cuda/future.hpp>
#include <cassert>
int main()
{
{
// int, int -> (int, int)
auto f1 = agency::cuda::make_ready_future<int>(7);
auto f2 = agency::cuda::make_ready_future<int>(13);
auto f3 = agency::cuda::when_all(f1, f2);
auto result = f3.get();
assert(result == agency::de... | bsd-3-clause | Cuda |
a93d1ea5dfd191acc2bfb81bab134b93c3617e4e | make TestDeviceDeleteDestructorInvocation a KNOWN_FAILURE | xiongzhanblake/thrust_src,andrewcorrigan/thrust-multi-permutation-iterator,xiongzhanblake/thrust_src,thvasilo/thrust,raygit/thrust,Ricardo666666/thrust,xiongzhanblake/thrust_src,Ricardo666666/thrust,jaredhoberock/thrust,mohamed-ali/thrust,egaburov/thrust,thvasilo/thrust,dachziegel/thrust,thrust/thrust,thrust/thrust,and... | testing/device_delete.cu | testing/device_delete.cu | #include <thrusttest/unittest.h>
#include <thrust/device_vector.h>
#include <thrust/device_ptr.h>
#include <thrust/device_new.h>
#include <thrust/device_delete.h>
struct Foo
{
__host__ __device__
Foo(void)
:set_me_upon_destruction(0)
{}
__host__ __device__
~Foo(void)
{
#ifdef __CUDA_AR... | #include <thrusttest/unittest.h>
#include <thrust/device_vector.h>
#include <thrust/device_ptr.h>
#include <thrust/device_new.h>
#include <thrust/device_delete.h>
struct Foo
{
__host__ __device__
Foo(void)
:set_me_upon_destruction(0)
{}
__host__ __device__
~Foo(void)
{
#ifdef __CUDA_AR... | apache-2.0 | Cuda |
adff6a5379050115f449a54d53715581c3c794bc | Test tabulate with thrust::device in __device__ code. | Ricardo666666/thrust,andrewcorrigan/thrust-multi-permutation-iterator,xiongzhanblake/thrust_src,mohamed-ali/thrust,GrimDerp/thrust,zhenglaizhang/thrust,Ricardo666666/thrust,xiongzhanblake/thrust,zhenglaizhang/thrust,zhenglaizhang/thrust,raygit/thrust,sarvex/thrust,dachziegel/thrust,xiongzhanblake/thrust,raygit/thrust,r... | testing/backend/cuda/tabulate.cu | testing/backend/cuda/tabulate.cu | #include <unittest/unittest.h>
#include <thrust/tabulate.h>
#include <thrust/functional.h>
#include <thrust/execution_policy.h>
template<typename ExecutionPolicy, typename Iterator, typename Function>
__global__
void tabulate_kernel(ExecutionPolicy exec, Iterator first, Iterator last, Function f)
{
thrust::tabulate... | #include <unittest/unittest.h>
#include <thrust/tabulate.h>
#include <thrust/functional.h>
#include <thrust/execution_policy.h>
template<typename Iterator, typename Function>
__global__
void tabulate_kernel(Iterator first, Iterator last, Function f)
{
thrust::tabulate(thrust::seq, first, last, f);
}
void TestTabu... | apache-2.0 | Cuda |
846f2c3cce8b937637e0b46a7f62be068b835ade | fix GPU data race | wangg12/caffe,gnina/gnina,CZCV/s-dilation-caffe,wangg12/caffe,gnina/gnina,longjon/caffe,tackgeun/caffe,longjon/caffe,gnina/gnina,gnina/gnina,wangg12/caffe,tackgeun/caffe,tackgeun/caffe,wangg12/caffe,CZCV/s-dilation-caffe,gnina/gnina,gnina/gnina,tackgeun/caffe,CZCV/s-dilation-caffe,longjon/caffe,longjon/caffe,CZCV/s-dil... | src/caffe/layers/base_data_layer.cu | src/caffe/layers/base_data_layer.cu | #include <vector>
#include "caffe/data_layers.hpp"
namespace caffe {
template <typename Dtype>
void BasePrefetchingDataLayer<Dtype>::Forward_gpu(
const vector<Blob<Dtype>*>& bottom, const vector<Blob<Dtype>*>& top) {
Batch<Dtype>* batch = prefetch_full_.pop("Data layer prefetch queue empty");
// Reshape to l... | #include <vector>
#include "caffe/data_layers.hpp"
namespace caffe {
template <typename Dtype>
void BasePrefetchingDataLayer<Dtype>::Forward_gpu(
const vector<Blob<Dtype>*>& bottom, const vector<Blob<Dtype>*>& top) {
Batch<Dtype>* batch = prefetch_full_.pop("Data layer prefetch queue empty");
// Reshape to l... | apache-2.0 | Cuda |
65a32b6c8fa2c5e234bb2c38a6b191b337eca73d | print device ids | cholla-hydro/cholla,cholla-hydro/cholla,evaneschneider/cholla,evaneschneider/cholla,cholla-hydro/cholla,evaneschneider/cholla,evaneschneider/cholla,cholla-hydro/cholla | src/cuda_mpi_routines.cu | src/cuda_mpi_routines.cu | #include<stdio.h>
#include"gpu.hpp"
#include"io.h"
#include"cuda_mpi_routines.h"
/*! \fn int initialize_cuda_mpi(int myid, int nprocs);
* \brief CUDA initialization within MPI. */
int initialize_cuda_mpi(int myid, int nprocs)
{
int i_device = 0; //GPU device for this process
int n_device; //number of GPU dev... | #include<stdio.h>
#include"gpu.hpp"
#include"io.h"
#include"cuda_mpi_routines.h"
/*! \fn int initialize_cuda_mpi(int myid, int nprocs);
* \brief CUDA initialization within MPI. */
int initialize_cuda_mpi(int myid, int nprocs)
{
int i_device = 0; //GPU device for this process
int n_device; //number of GPU dev... | mit | Cuda |
fb032540172ca7b8a9ecd645de0a34d162335574 | Add FPS show in title and turn off vsync | Alice-MadHatter/IronFilings,Alice-MadHatter/IronFilings | IronFilings/application.cu | IronFilings/application.cu | #include "application.cuh"
GLFWwindow* Application::window = NULL;
string Application::title = "Hello, Iron Filings!";
int Application::width = 1024;
int Application::height = 768;
bool Application::fullscreen = false;
kmap Application::keyboardMap;
vec2 Application::mousePosition(0.0f);
Application::Application(stri... | #include "application.cuh"
GLFWwindow* Application::window = NULL;
string Application::title = "Hello, Iron Filings!";
int Application::width = 1024;
int Application::height = 768;
bool Application::fullscreen = false;
kmap Application::keyboardMap;
vec2 Application::mousePosition(0.0f);
Application::Application(stri... | apache-2.0 | Cuda |
e5988c67997dde83c5077cda3851a5b1394bf0ed | Fix banchmarking | marian-nmt/marian-train,DianaDespa/marian-train,marian-nmt/marian-train,DianaDespa/marian-train,marian-nmt/marian-train,emjotde/amunmt,DianaDespa/marian-train,marian-nmt/marian-train,emjotde/amunn,emjotde/amunn,DianaDespa/marian-train,emjotde/amunmt,amunmt/marian,emjotde/Marian,amunmt/marian,emjotde/Marian,marian-nmt/m... | src/test/dropout_test.cu | src/test/dropout_test.cu | #include <stdio.h>
#include <stdlib.h>
#include <cuda.h>
#include <curand.h>
#include <boost/timer/timer.hpp>
#include <boost/chrono.hpp>
#include "tensors/tensor_allocator.h"
#include "tensors/tensor.h"
#include "kernels/tensor_operators.h"
#include "layers/dropout.h"
#include "kernels/dropout_cudnn.h"
using names... | #include <stdio.h>
#include <stdlib.h>
#include <cuda.h>
#include <curand.h>
#include <boost/timer/timer.hpp>
#include <boost/chrono.hpp>
#include "tensors/tensor_allocator.h"
#include "tensors/tensor.h"
#include "kernels/tensor_operators.h"
#include "layers/dropout.h"
#include "kernels/dropout_cudnn.h"
using names... | mit | Cuda |
1197bd03113ba631f4183e195726dce5e8a91c3c | Tweak not to match "clang" to other place like "path-to-clang-foo". | apple/swift-clang,apple/swift-clang,apple/swift-clang,llvm-mirror/clang,llvm-mirror/clang,apple/swift-clang,llvm-mirror/clang,apple/swift-clang,apple/swift-clang,llvm-mirror/clang,llvm-mirror/clang,llvm-mirror/clang,apple/swift-clang,llvm-mirror/clang,llvm-mirror/clang,apple/swift-clang,apple/swift-clang,llvm-mirror/cl... | test/Driver/cuda-march.cu | test/Driver/cuda-march.cu | // Checks that cuda compilation does the right thing when passed -march.
// (Specifically, we want to pass it to host compilation, but not to device
// compilation or ptxas!)
//
// REQUIRES: clang-driver
// REQUIRES: x86-registered-target
// REQUIRES: nvptx-registered-target
// RUN: %clang -### -target x86_64-linux-gn... | // Checks that cuda compilation does the right thing when passed -march.
// (Specifically, we want to pass it to host compilation, but not to device
// compilation or ptxas!)
//
// REQUIRES: clang-driver
// REQUIRES: x86-registered-target
// REQUIRES: nvptx-registered-target
// RUN: %clang -### -target x86_64-linux-gn... | apache-2.0 | Cuda |
d858f8b8ac53eb788cab97036da0e40c46cedf71 | Fix typo in tuple_scan.cu | thrust/thrust,thrust/thrust,sdalton1/thrust,andrewcorrigan/thrust-multi-permutation-iterator,sdalton1/thrust,dachziegel/thrust,Ricardo666666/thrust,xiongzhanblake/thrust_src,dachziegel/thrust,raygit/thrust,Ricardo666666/thrust,marksantos/thrust,arnabgho/thrust,jaredhoberock/thrust,zhenglaizhang/thrust,arnabgho/thrust,z... | testing/tuple_scan.cu | testing/tuple_scan.cu | #include <unittest/unittest.h>
#include <thrust/tuple.h>
#include <thrust/scan.h>
#include <thrust/transform.h>
using namespace unittest;
using namespace thrust;
template <typename Tuple>
__host__ __device__
Tuple operator+(const Tuple &lhs, const Tuple &rhs)
{
return make_tuple(get<0>(lhs) + get<0>(rhs),
... | #include <unittest/unittest.h>
#include <thrust/tuple.h>
#include <thrust/scan.h>
#include <thrust/transform.h>
using namespace unittest;
using namespace thrust;
template <typename Tuple>
__host__ __device__
Tuple operator+(const Tuple &lhs, const Tuple &rhs)
{
return make_tuple(get<0>(lhs) + get<0>(rhs),
... | apache-2.0 | Cuda |
66cc45afc560f5b58a73b3c922d583f9b1b75a59 | Migrate lit test to using FileCheck, so failures are readable | ROCm-Developer-Tools/HIP,ROCm-Developer-Tools/HIP,ROCm-Developer-Tools/HIP,ROCm-Developer-Tools/HIP,GPUOpen-ProfessionalCompute-Tools/HIP,GPUOpen-ProfessionalCompute-Tools/HIP,GPUOpen-ProfessionalCompute-Tools/HIP,ROCm-Developer-Tools/HIP,GPUOpen-ProfessionalCompute-Tools/HIP,GPUOpen-ProfessionalCompute-Tools/HIP | tests/hipify-clang/axpy.cu | tests/hipify-clang/axpy.cu | // RUN: hipify "%s" -o=%t -- %cuda_args && cat %t | sed -Ee 's|//.+|// |g' | FileCheck %s
#include <iostream>
__global__ void axpy(float a, float* x, float* y) {
// CHECK: y[hipThreadIdx_x] = a * x[hipThreadIdx_x];
y[threadIdx.x] = a * x[threadIdx.x];
}
int main(int argc, char* argv[]) {
const int kDataLen = 4... | // RUN: hipify "%s" -o=%t -- %cuda_args
#include <iostream>
__global__ void axpy(float a, float* x, float* y) {
// RUN: sh -c "test `grep -c -F 'y[hipThreadIdx_x] = a * x[hipThreadIdx_x];' %t` -eq 2"
y[threadIdx.x] = a * x[threadIdx.x];
}
int main(int argc, char* argv[]) {
const int kDataLen = 4;
float a = ... | mit | Cuda |
c326aae0cf9b975960a5e657ce4174ea795b78bb | Fix code style in gaussian_random_op.cu | chengduoZH/Paddle,chengduoZH/Paddle,baidu/Paddle,lcy-seso/Paddle,Canpio/Paddle,hedaoyuan/Paddle,hedaoyuan/Paddle,putcn/Paddle,baidu/Paddle,yu239/Paddle,jacquesqiao/Paddle,reyoung/Paddle,lispc/Paddle,pengli09/Paddle,lcy-seso/Paddle,tensor-tang/Paddle,luotao1/Paddle,putcn/Paddle,QiJune/Paddle,tensor-tang/Paddle,lispc/Pad... | paddle/operators/gaussian_random_op.cu | paddle/operators/gaussian_random_op.cu | /* Copyright (c) 2016 PaddlePaddle Authors. All Rights Reserve.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applica... | /* Copyright (c) 2016 PaddlePaddle Authors. All Rights Reserve.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applica... | apache-2.0 | Cuda |
93750a59cd4e48725c6e95d7a6c8cc1697271deb | Test transform_reduce with thrust::device in __device__ code. | thrust/thrust,Ricardo666666/thrust,zeryx/thrust,zhenglaizhang/thrust,marksantos/thrust,marksantos/thrust,zhenglaizhang/thrust,mohamed-ali/thrust,GrimDerp/thrust,dachziegel/thrust,egaburov/thrust,thvasilo/thrust,andrewcorrigan/thrust-multi-permutation-iterator,thrust/thrust,raygit/thrust,raygit/thrust,xiongzhanblake/thr... | testing/backend/cuda/transform_reduce.cu | testing/backend/cuda/transform_reduce.cu | #include <unittest/unittest.h>
#include <thrust/transform_reduce.h>
#include <thrust/execution_policy.h>
template<typename ExecutionPolicy, typename Iterator1, typename Function1, typename T, typename Function2, typename Iterator2>
__global__
void transform_reduce_kernel(ExecutionPolicy exec, Iterator1 first, Iterato... | #include <unittest/unittest.h>
#include <thrust/transform_reduce.h>
#include <thrust/execution_policy.h>
template<typename Iterator1, typename Function1, typename T, typename Function2, typename Iterator2>
__global__
void transform_reduce_kernel(Iterator1 first, Iterator1 last, Function1 f1, T init, Function2 f2, Ite... | apache-2.0 | Cuda |
e285d4d86abfd72189559651b3eea272db05f920 | include N_RA defn | SLACKHA/accelerInt,SLACKHA/accelerInt,SLACKHA/accelerInt,SLACKHA/accelerInt | src/rational_approximant.cu | src/rational_approximant.cu | /*rational_approximant.cu
* The generic initialization file for poles/hosts for RA based evaulation of the matrix exponential
* \file rational_approximant.cu
*
* \author Nicholas Curtis
* \date 03/09/2015
*
* Contains initialization and declaration of RA
*/
//cf
#include <cuComplex.h>
#include "header.h"
extern "C" {
... | /*rational_approximant.cu
* The generic initialization file for poles/hosts for RA based evaulation of the matrix exponential
* \file rational_approximant.cu
*
* \author Nicholas Curtis
* \date 03/09/2015
*
* Contains initialization and declaration of RA
*/
//cf
#include <cuComplex.h>
#include "header.h"
extern "C" {
... | mit | Cuda |
6602f44b08eca713718b892b5830af2cea00f3c2 | Mark TestTransformNullPtr as a KNOWN_FAILURE on Windows | Ricardo666666/thrust,GrimDerp/thrust,sarvex/thrust,arnabgho/thrust,xiongzhanblake/thrust_src,raygit/thrust,thrust/thrust,andrewcorrigan/thrust-multi-permutation-iterator,mohamed-ali/thrust,thvasilo/thrust,marksantos/thrust,raygit/thrust,zeryx/thrust,andrewcorrigan/thrust-multi-permutation-iterator,sdalton1/thrust,xiong... | testing/debug.cu | testing/debug.cu | #define THRUST_DEBUG 1
#include <unittest/unittest.h>
#include <thrust/device_ptr.h>
#include <thrust/transform.h>
#include <thrust/reduce.h>
#include <thrust/scan.h>
#include <thrust/sort.h>
#include <thrust/system_error.h>
#if THRUST_DEVICE_BACKEND == THRUST_DEVICE_BACKEND_CUDA
void TestTransformNullPtr(void)
{
#i... | #define THRUST_DEBUG 1
#include <unittest/unittest.h>
#include <thrust/device_ptr.h>
#include <thrust/transform.h>
#include <thrust/reduce.h>
#include <thrust/scan.h>
#include <thrust/sort.h>
#include <thrust/system_error.h>
#if THRUST_DEVICE_BACKEND == THRUST_DEVICE_BACKEND_CUDA
void TestTransformNullPtr(void)
{
#i... | apache-2.0 | Cuda |
4325a5549200ccf059af4579ff2ea4c74de03455 | Use begin + 5 instead of end in examples/complicated_transform.cu | jbrownbridge/thrust,jbrownbridge/thrust,jbrownbridge/thrust,jbrownbridge/thrust | examples/complicated_transformation.cu | examples/complicated_transformation.cu | #include <thrust/for_each.h>
#include <thrust/iterator/counting_iterator.h>
#include <thrust/generate.h>
#include <thrust/iterator/iterator_traits.h>
#include <thrust/device_ptr.h>
#include <thrust/host_vector.h>
#include <thrust/device_vector.h>
#include <iostream>
#include <cstdlib>
// this example shows how to impl... | #include <thrust/for_each.h>
#include <thrust/iterator/counting_iterator.h>
#include <thrust/generate.h>
#include <thrust/iterator/iterator_traits.h>
#include <thrust/device_ptr.h>
#include <thrust/host_vector.h>
#include <thrust/device_vector.h>
#include <iostream>
#include <cstdlib>
// this example shows how to impl... | apache-2.0 | Cuda |
150a37e2510b1eacd3140c4b5e63cb39d0613f31 | add kernel func | stormHan/Parallel_RVD,stormHan/Parallel_RVD | Parallel_RVD/Cudaclass.cu | Parallel_RVD/Cudaclass.cu | #include "cuda_runtime.h"
#include "device_launch_parameters.h"
#include <iostream>
/*
process the cuda error
*/
inline void checkCudaErrors(cudaError err)
{
if (cudaSuccess != err)
{
fprintf(stderr, "CUDA Runtime API error : %s.\n", cudaGetErrorString(err));
return;
}
}
/*
a thread to compute the RVD in par... | #include "cuda_runtime.h"
#include "device_launch_parameters.h"
#include <iostream>
/*
process the cuda error
*/
inline void checkCudaErrors(cudaError err)
{
if (cudaSuccess != err)
{
fprintf(stderr, "CUDA Runtime API error : %s.\n", cudaGetErrorString(err));
return;
}
}
extern "C" void runCuda(double* host_s... | mit | Cuda |
87f4a681ae3f4c73e8ad004977993d3d4cd18c4c | Fix trace conflict (#39421) | luotao1/Paddle,PaddlePaddle/Paddle,luotao1/Paddle,luotao1/Paddle,PaddlePaddle/Paddle,luotao1/Paddle,luotao1/Paddle,luotao1/Paddle,PaddlePaddle/Paddle,PaddlePaddle/Paddle,PaddlePaddle/Paddle,PaddlePaddle/Paddle,luotao1/Paddle,PaddlePaddle/Paddle | paddle/pten/kernels/gpu/trace_kernel.cu | paddle/pten/kernels/gpu/trace_kernel.cu | // Copyright (c) 2022 PaddlePaddle Authors. All Rights Reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required... | // Copyright (c) 2022 PaddlePaddle Authors. All Rights Reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required... | apache-2.0 | Cuda |
fcac3b67798126be8a8a35a65330db99c6bfe0c8 | test for size of pixel | NandoSerrano85/CDA4101-project | main.cu | main.cu | /*
Team: Packers
PID: 5642858
Class: CDA4101 Section: U02
Affirmation:
"I affirm that this program is entirely
my own work and none of it is the work
of any other person."
*/
#include <stdlib.h>
#include <stdio.h>
#include <ctype.h>
#include <unistd.h>
#include "bmplib.h"
#define TRUE = 1
/*
//cuda function
__glob... | /*
Team: Packers
PID: 5642858
Class: CDA4101 Section: U02
Affirmation:
"I affirm that this program is entirely
my own work and none of it is the work
of any other person."
*/
#include <stdlib.h>
#include <stdio.h>
#include <ctype.h>
#include <unistd.h>
#include "bmplib.h"
#define TRUE = 1
//cuda function
__global... | apache-2.0 | Cuda |
bfe9d46ba2ed65079c5495156442d10601c1ca4c | fix Tensor | stormmax/Teaism,stormmax/Teaism,stormmax/Teaism,stormmax/Teaism | basics/tensor.cu | basics/tensor.cu | #ifndef TENSOR_CUH_
#define TENSOR_CUH_
#include <vector>
#include <assert.h>
#include <cstdlib>
#include <numeric>
#include <functional>
#include <iostream>
#include "basics/session.hpp"
#include "cuda_runtime.h"
#include "utils/helper_cuda.h"
template<class Dtype>
class Tensor {
public:
__host__ __device__ Ten... | #ifndef TENSOR_CUH_
#define TENSOR_CUH_
#include <vector>
#include <assert.h>
#include <cstdlib>
#include <numeric>
#include <functional>
#include <iostream>
#include "basics/session.hpp"
#include "cuda_runtime.h"
#include "utils/helper_cuda.h"
template<class Dtype>
class Tensor {
public:
__host__ __device__ Ten... | mit | Cuda |
cbff2255bc8470299e15cc155ae7957a3acdd688 | add CUDA kernels | wangg12/caffe,CZCV/s-dilation-caffe,CZCV/s-dilation-caffe,wangg12/caffe,gnina/gnina,gnina/gnina,tackgeun/caffe,longjon/caffe,CZCV/s-dilation-caffe,gnina/gnina,gnina/gnina,gnina/gnina,longjon/caffe,CZCV/s-dilation-caffe,tackgeun/caffe,gnina/gnina,tackgeun/caffe,wangg12/caffe,wangg12/caffe,longjon/caffe,longjon/caffe,tac... | src/caffe/layers/tile_layer.cu | src/caffe/layers/tile_layer.cu | #include <vector>
#include "caffe/common_layers.hpp"
#include "caffe/layer.hpp"
#include "caffe/util/math_functions.hpp"
namespace caffe {
template <typename Dtype>
__global__ void Tile(const int nthreads, const Dtype* bottom_data,
const int tile_size, const int num_tiles, const int bottom_tile_axis,
Dtype* ... | #include <vector>
#include "caffe/common_layers.hpp"
#include "caffe/layer.hpp"
#include "caffe/util/math_functions.hpp"
namespace caffe {
template <typename Dtype>
void TileLayer<Dtype>::Forward_gpu(
const vector<Blob<Dtype>*>& bottom, const vector<Blob<Dtype>*>& top) {
const Dtype* bottom_data = bottom[0]->g... | agpl-3.0 | Cuda |
7a12e2ef1e8d5d2ac58fad71e5ae442dae1dccfa | Make this test program match the .cpp version | egaburov/agency,egaburov/agency | test_is_executor.cu | test_is_executor.cu | #include <agency/cuda/grid_executor.hpp>
#include <agency/cuda/parallel_executor.hpp>
#include <agency/cuda/concurrent_executor.hpp>
#include <agency/nested_executor.hpp>
#include <agency/concurrent_executor.hpp>
#include <agency/sequential_executor.hpp>
#include <agency/executor_traits.hpp>
#include <iostream>
int ma... | #include <agency/cuda/grid_executor.hpp>
#include <agency/cuda/parallel_executor.hpp>
#include <agency/cuda/concurrent_executor.hpp>
#include <agency/nested_executor.hpp>
#include <agency/concurrent_executor.hpp>
#include <agency/sequential_executor.hpp>
#include <agency/executor_traits.hpp>
#include <iostream>
int ma... | bsd-3-clause | Cuda |
26950c09e79860fa0fca25a48a7bebbde13aaea6 | Test uninitialized_copy with thrust::device in __device__ code. | Ricardo666666/thrust,zeryx/thrust,dachziegel/thrust,GrimDerp/thrust,thrust/thrust,sarvex/thrust,dachziegel/thrust,sarvex/thrust,xiongzhanblake/thrust_src,jaredhoberock/thrust,marksantos/thrust,jaredhoberock/thrust,arnabgho/thrust,arnabgho/thrust,zeryx/thrust,thvasilo/thrust,egaburov/thrust,xiongzhanblake/thrust,GrimDer... | testing/backend/cuda/uninitialized_copy.cu | testing/backend/cuda/uninitialized_copy.cu | #include <unittest/unittest.h>
#include <thrust/uninitialized_copy.h>
#include <thrust/execution_policy.h>
template<typename ExecutionPolicy, typename Iterator1, typename Iterator2>
__global__
void uninitialized_copy_kernel(ExecutionPolicy exec, Iterator1 first, Iterator1 last, Iterator2 result)
{
thrust::uninitial... | #include <unittest/unittest.h>
#include <thrust/uninitialized_copy.h>
#include <thrust/execution_policy.h>
template<typename Iterator1, typename Iterator2>
__global__
void uninitialized_copy_kernel(Iterator1 first, Iterator1 last, Iterator2 result)
{
thrust::uninitialized_copy(thrust::seq, first, last, result);
}
... | apache-2.0 | Cuda |
c5640dbb916b0a2130f4fbe508b04d3c45bc4053 | Add a test for future_traits::cast() | egaburov/agency,egaburov/agency | testing/cuda/test_future_cast.cu | testing/cuda/test_future_cast.cu | #include <agency/cuda/future.hpp>
#include <agency/future.hpp>
#include <iostream>
#include <cassert>
struct empty {};
int main()
{
{
// construction of future<void> from empty types
using future_type1 = agency::cuda::future<empty>;
future_type1 f1 = agency::cuda::make_ready_future(empty());
using... | #include <agency/cuda/future.hpp>
#include <agency/future.hpp>
#include <iostream>
#include <cassert>
struct empty {};
int main()
{
{
// construction of future<void> from empty types
using future_type1 = agency::cuda::future<empty>;
future_type1 f1 = agency::cuda::make_ready_future(empty());
using... | bsd-3-clause | Cuda |
914b2a24c1f5c2a44ea27457911ebc98e75daed8 | Add self loop unit test | gunrock/gunrock,gunrock/gunrock,gunrock/gunrock | unittests/algorithms/tc.cuh | unittests/algorithms/tc.cuh | /**
* @file tc.cuh
* @author Muhammad A. Awad (mawad@ucdavis.edu)
* @brief Unit test for the triangle counting algorithm.
* @version 0.1
* @date 2022-17-06
*
* @copyright Copyright (c) 2022
*
*/
#include <gunrock/graph/graph.hxx>
#include <gunrock/formats/formats.hxx>
#include <gunrock/algorithms/tc.hxx>
usi... | /**
* @file tc.cuh
* @author Muhammad A. Awad (mawad@ucdavis.edu)
* @brief Unit test for the triangle counting algorithm.
* @version 0.1
* @date 2022-17-06
*
* @copyright Copyright (c) 2022
*
*/
#include <gunrock/graph/graph.hxx>
#include <gunrock/formats/formats.hxx>
#include <gunrock/algorithms/tc.hxx>
usi... | apache-2.0 | Cuda |
ed23b6890612d9f21b0edb93ee0b9d0bca1b48dc | fix softmax loss layer bug; all tests pass | MoskalenkoViktor/caffe,shiquanwang/caffe,niuzhiheng/caffe,minghuam/caffe,minghuam/caffe,gnina/gnina,audtlr24/caffe,xidianwlc/caffe,liuxianming/caffe_feedback,Hilovaiserillis/caffe,Hilovaiserillis/caffe,orentadmor/caffe,CZCV/s-dilation-caffe,gogartom/caffe-textmaps,sichenucsd/caffe_si,CZCV/s-dilation-caffe,wangg12/caffe... | src/caffe/layers/softmax_loss_layer.cu | src/caffe/layers/softmax_loss_layer.cu | // Copyright 2013 Yangqing Jia
#include <algorithm>
#include <cfloat>
#include <vector>
#include "caffe/layer.hpp"
#include "caffe/vision_layers.hpp"
#include "caffe/util/math_functions.hpp"
using std::max;
namespace caffe {
template <typename Dtype>
Dtype SoftmaxWithLossLayer<Dtype>::Forward_gpu(
const vector... | // Copyright 2013 Yangqing Jia
#include <algorithm>
#include <cfloat>
#include <vector>
#include "caffe/layer.hpp"
#include "caffe/vision_layers.hpp"
#include "caffe/util/math_functions.hpp"
using std::max;
namespace caffe {
template <typename Dtype>
Dtype SoftmaxWithLossLayer<Dtype>::Forward_gpu(
const vector... | bsd-2-clause | Cuda |
1ba24a759781485690b60ba4536d902c409ad6c9 | Remove redundant sketching. (#5700) | dmlc/xgboost,dmlc/xgboost,dmlc/xgboost,dmlc/xgboost,dmlc/xgboost,dmlc/xgboost | src/data/device_dmatrix.cu | src/data/device_dmatrix.cu | /*!
* Copyright 2020 by Contributors
* \file device_dmatrix.cu
* \brief Device-memory version of DMatrix.
*/
#include <thrust/execution_policy.h>
#include <thrust/iterator/discard_iterator.h>
#include <thrust/iterator/transform_output_iterator.h>
#include <xgboost/base.h>
#include <xgboost/data.h>
#include <memory... | /*!
* Copyright 2020 by Contributors
* \file device_dmatrix.cu
* \brief Device-memory version of DMatrix.
*/
#include <thrust/execution_policy.h>
#include <thrust/iterator/discard_iterator.h>
#include <thrust/iterator/transform_output_iterator.h>
#include <xgboost/base.h>
#include <xgboost/data.h>
#include <memory... | apache-2.0 | Cuda |
f779a367f15da9db40a8d79ffdbbb650f6bb7d41 | Fix chainerx.maximum to restore CUDA device | wkentaro/chainer,hvy/chainer,pfnet/chainer,okuta/chainer,niboshi/chainer,keisuke-umezawa/chainer,wkentaro/chainer,chainer/chainer,okuta/chainer,chainer/chainer,hvy/chainer,niboshi/chainer,keisuke-umezawa/chainer,hvy/chainer,chainer/chainer,wkentaro/chainer,okuta/chainer,chainer/chainer,wkentaro/chainer,niboshi/chainer,... | chainerx_cc/chainerx/cuda/cuda_device/activation.cu | chainerx_cc/chainerx/cuda/cuda_device/activation.cu | #include "chainerx/cuda/cuda_device.h"
#include <cmath>
#include <cstdint>
#include <cuda_runtime.h>
#include "chainerx/array.h"
#include "chainerx/cuda/cuda_runtime.h"
#include "chainerx/cuda/cuda_set_device_scope.h"
#include "chainerx/cuda/elementwise.cuh"
#include "chainerx/device.h"
#include "chainerx/dtype.h"
#... | #include "chainerx/cuda/cuda_device.h"
#include <cmath>
#include <cstdint>
#include <cuda_runtime.h>
#include "chainerx/array.h"
#include "chainerx/cuda/cuda_runtime.h"
#include "chainerx/cuda/cuda_set_device_scope.h"
#include "chainerx/cuda/elementwise.cuh"
#include "chainerx/device.h"
#include "chainerx/dtype.h"
#... | mit | Cuda |
78c12060ebd9eb9737eccf98ebe57e87128b3da1 | Add header to CUDAMemoryManager.cuh | GOMC-WSU/GOMC,GOMC-WSU/GOMC,GOMC-WSU/GOMC,GOMC-WSU/GOMC,GOMC-WSU/GOMC | src/GPU/CUDAMemoryManager.cuh | src/GPU/CUDAMemoryManager.cuh | /*******************************************************************************
GPU OPTIMIZED MONTE CARLO (GOMC) 2.70
Copyright (C) 2018 GOMC Group
A copy of the GNU General Public License can be found in the COPYRIGHT.txt
along with this program, also can be found at <http://www.gnu.org/licenses/>.
*****************... | #pragma once
#ifdef GOMC_CUDA
#include <cuda.h>
#include <cuda_runtime.h>
#include <unordered_map>
#include <iostream>
#define CUMALLOC(address,size) CUDAMemoryManager::mallocMemory(address,size,#address)
#define CUFREE(address) CUDAMemoryManager::freeMemory(address,#address)
class CUDAMemoryManager
{
public:
stati... | mit | Cuda |
524b888bc305166e67a5e203d4707d299fe13c74 | use function in cuda_fp16.h, because device_functions_decls.h is unavailable on CUDA 9.1 and later | cupy/cupy,cupy/cupy,cupy/cupy,cupy/cupy | cupy/core/include/cupy/atomics.cuh | cupy/core/include/cupy/atomics.cuh | #pragma once
#if __CUDA_ARCH__ < 600
__device__ double atomicAdd(double *address, double val)
{
unsigned long long int* address_as_ull = (unsigned long long int*)address;
unsigned long long int old = *address_as_ull;
unsigned long long int assumed;
do {
assumed = old;
old = atomicCAS(address_as_ull,... | #pragma once
#if __CUDA_ARCH__ < 600
__device__ double atomicAdd(double *address, double val)
{
unsigned long long int* address_as_ull = (unsigned long long int*)address;
unsigned long long int old = *address_as_ull;
unsigned long long int assumed;
do {
assumed = old;
old = atomicCAS(address_as_ull,... | mit | Cuda |
38b612e6c7ee3a0eb9761d80e5d2d6d734acb47a | Fix typo. | NVlabs/cub,NVlabs/CUB,NVIDIA/cub | cub/detail/device_synchronize.cuh | cub/detail/device_synchronize.cuh | /*
* Copyright 2021 NVIDIA Corporation
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law ... | /*
* Copyright 2021 NVIDIA Corporation
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law ... | bsd-3-clause | Cuda |
2b2bd4fc7f9047b567384443c9bbb6db32e04485 | Update HarmonicDihedralForceGPU.cuh for additional coefficient, use Scalar5 | joaander/hoomd-blue,joaander/hoomd-blue,joaander/hoomd-blue,joaander/hoomd-blue,joaander/hoomd-blue,joaander/hoomd-blue | hoomd/md/HarmonicDihedralForceGPU.cuh | hoomd/md/HarmonicDihedralForceGPU.cuh | // Copyright (c) 2009-2019 The Regents of the University of Michigan
// This file is part of the HOOMD-blue project, released under the BSD 3-Clause License.
// Maintainer: dnlebard
#include "hoomd/ParticleData.cuh"
#include "hoomd/HOOMDMath.h"
#include "hoomd/BondedGroupData.cuh"
/*! \file HarmonicDihedralForceGPU... | // Copyright (c) 2009-2019 The Regents of the University of Michigan
// This file is part of the HOOMD-blue project, released under the BSD 3-Clause License.
// Maintainer: dnlebard
#include "hoomd/ParticleData.cuh"
#include "hoomd/HOOMDMath.h"
#include "hoomd/BondedGroupData.cuh"
/*! \file HarmonicDihedralForceGPU... | bsd-3-clause | Cuda |
1a90349b30e0c6ccb02b17037e4d051f48ae3fc5 | make isFreed() function public | GOMC-WSU/GOMC,GOMC-WSU/GOMC,GOMC-WSU/GOMC,GOMC-WSU/GOMC_Serial,GOMC-WSU/GOMC_Serial,GOMC-WSU/GOMC_Serial,GOMC-WSU/GOMC,GOMC-WSU/GOMC | src/GPU/CUDAMemoryManager.cuh | src/GPU/CUDAMemoryManager.cuh | #pragma once
#ifdef GOMC_CUDA
#include <cuda.h>
#include <cuda_runtime.h>
#include <unordered_map>
#include <iostream>
class CUDAMemoryManager {
public:
static cudaError_t mallocMemory(void **address, unsigned int size);
static cudaError_t freeMemory(void *address);
static bool isFreed();
private:
static long... | #pragma once
#ifdef GOMC_CUDA
#include <cuda.h>
#include <cuda_runtime.h>
#include <unordered_map>
#include <iostream>
class CUDAMemoryManager {
public:
static cudaError_t mallocMemory(void **address, unsigned int size);
static cudaError_t freeMemory(void *address);
private:
static long long totalAllocatedBytes... | mit | Cuda |
6530d95557600fd083dd6a4763c7b559a9a991ef | add def of void InitExp6Variables to header file | GOMC-WSU/GOMC_Serial,GOMC-WSU/GOMC,GOMC-WSU/GOMC,GOMC-WSU/GOMC,GOMC-WSU/GOMC,GOMC-WSU/GOMC_Serial,GOMC-WSU/GOMC_Serial,GOMC-WSU/GOMC | src/GPU/ConstantDefinitionsCUDAKernel.cuh | src/GPU/ConstantDefinitionsCUDAKernel.cuh | /*******************************************************************************
GPU OPTIMIZED MONTE CARLO (GOMC) 2.40
Copyright (C) 2018 GOMC Group
A copy of the GNU General Public License can be found in the COPYRIGHT.txt
along with this program, also can be found at <http://www.gnu.org/licenses/>.
*****************... | /*******************************************************************************
GPU OPTIMIZED MONTE CARLO (GOMC) 2.40
Copyright (C) 2018 GOMC Group
A copy of the GNU General Public License can be found in the COPYRIGHT.txt
along with this program, also can be found at <http://www.gnu.org/licenses/>.
*****************... | mit | Cuda |
209cfdad0390250e8898aadbb7c38c80bb085537 | Test uninitialized_copy with thrust::device in __device__ code. | jaredhoberock/thrust,thrust/thrust,thvasilo/thrust,xiongzhanblake/thrust_src,andrewcorrigan/thrust-multi-permutation-iterator,jaredhoberock/thrust,mohamed-ali/thrust,marksantos/thrust,zhenglaizhang/thrust,xiongzhanblake/thrust_src,sdalton1/thrust,arnabgho/thrust,marksantos/thrust,xiongzhanblake/thrust,arnabgho/thrust,t... | testing/backend/cuda/uninitialized_copy.cu | testing/backend/cuda/uninitialized_copy.cu | #include <unittest/unittest.h>
#include <thrust/uninitialized_copy.h>
#include <thrust/execution_policy.h>
template<typename ExecutionPolicy, typename Iterator1, typename Iterator2>
__global__
void uninitialized_copy_kernel(ExecutionPolicy exec, Iterator1 first, Iterator1 last, Iterator2 result)
{
thrust::uninitial... | #include <unittest/unittest.h>
#include <thrust/uninitialized_copy.h>
#include <thrust/execution_policy.h>
template<typename Iterator1, typename Iterator2>
__global__
void uninitialized_copy_kernel(Iterator1 first, Iterator1 last, Iterator2 result)
{
thrust::uninitialized_copy(thrust::seq, first, last, result);
}
... | apache-2.0 | Cuda |
24acf8d5f96809bb13ea4c7f4fd1b1b69e90ce90 | fix cuda-8.0 compile ISSUE=4613907 | comeonfox/Paddle,reyoung/Paddle,jacquesqiao/Paddle,wen-bo-yang/Paddle,dayhaha/Paddle,lispc/Paddle,baidu/Paddle,baidu/Paddle,comeonfox/Paddle,alvations/Paddle,emailweixu/Paddle,dayhaha/Paddle,QiJune/Paddle,yu239/Paddle,tensor-tang/Paddle,gangliao/Paddle,pengli09/Paddle,cxysteven/Paddle,chengduoZH/Paddle,dayhaha/Paddle,l... | paddle/cuda/include/hl_device_functions.cuh | paddle/cuda/include/hl_device_functions.cuh | /* Copyright (c) 2016 Baidu, Inc. All Rights Reserve.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to ... | /* Copyright (c) 2016 Baidu, Inc. All Rights Reserve.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to ... | apache-2.0 | Cuda |
5d6c81687c74fd8f3435b84ef6865edf179c0a57 | Use begin + 5 instead of end in examples/complicated_transform.cu | mohamed-ali/thrust,egaburov/thrust,marksantos/thrust,zeryx/thrust,thvasilo/thrust,arnabgho/thrust,sdalton1/thrust,sarvex/thrust,xiongzhanblake/thrust_src,sarvex/thrust,jaredhoberock/thrust,xiongzhanblake/thrust,xiongzhanblake/thrust,GrimDerp/thrust,marksantos/thrust,dachziegel/thrust,Ricardo666666/thrust,dachziegel/thr... | examples/complicated_transformation.cu | examples/complicated_transformation.cu | #include <thrust/for_each.h>
#include <thrust/iterator/counting_iterator.h>
#include <thrust/generate.h>
#include <thrust/iterator/iterator_traits.h>
#include <thrust/device_ptr.h>
#include <thrust/host_vector.h>
#include <thrust/device_vector.h>
#include <iostream>
#include <cstdlib>
// this example shows how to impl... | #include <thrust/for_each.h>
#include <thrust/iterator/counting_iterator.h>
#include <thrust/generate.h>
#include <thrust/iterator/iterator_traits.h>
#include <thrust/device_ptr.h>
#include <thrust/host_vector.h>
#include <thrust/device_vector.h>
#include <iostream>
#include <cstdlib>
// this example shows how to impl... | apache-2.0 | Cuda |
67b93681c35ebe7f7c35c3d708202b2da8043b09 | fix not allocating vertexData array | RoyalCaliber/vertexAPI2,RoyalCaliber/vertexAPI2,RoyalCaliber/vertexAPI2 | bfs.cu | bfs.cu | //BFS using vertexAPI2
#include "util.h"
#include "graphio.h"
#include "refgas.h"
struct BFS
{
//global iteration count, terrible! OK, while we still figure out
//how to do the important stuff correctly, but correct method would
//be to add engine context to all the GAS prototypes
static int iterationCount;... | //BFS using vertexAPI2
#include "util.h"
#include "graphio.h"
#include "refgas.h"
struct BFS
{
//global iteration count, terrible! OK, while we still figure out
//how to do the important stuff correctly, but correct method would
//be to add engine context to all the GAS prototypes
static int iterationCount;... | apache-2.0 | Cuda |
5240ba5698fc167c5f124994ec80eb1a896528fd | Fix failure of lit test dependent-libs.cu | llvm-mirror/clang,llvm-mirror/clang,apple/swift-clang,llvm-mirror/clang,llvm-mirror/clang,llvm-mirror/clang,apple/swift-clang,apple/swift-clang,apple/swift-clang,llvm-mirror/clang,apple/swift-clang,llvm-mirror/clang,apple/swift-clang,apple/swift-clang,apple/swift-clang,apple/swift-clang,llvm-mirror/clang,apple/swift-cl... | test/CodeGenCUDA/dependent-libs.cu | test/CodeGenCUDA/dependent-libs.cu | // REQUIRES: x86-registered-target
// REQUIRES: amdgpu-registered-target
// RUN: %clang_cc1 -triple amdgcn-amd-amdhsa -emit-llvm -o - -fcuda-is-device -x hip %s | FileCheck --check-prefix=DEV %s
// RUN: %clang_cc1 -triple x86_64-linux-gnu -emit-llvm -o - -x hip %s | FileCheck --check-prefix=HOST %s
// DEV-NOT: llvm.de... | // RUN: %clang_cc1 -emit-llvm -o - -fcuda-is-device -x hip %s | FileCheck --check-prefix=DEV %s
// RUN: %clang_cc1 -emit-llvm -o - -x hip %s | FileCheck --check-prefix=HOST %s
// DEV-NOT: llvm.dependent-libraries
// HOST: llvm.dependent-libraries
#pragma comment(lib, "libabc")
| apache-2.0 | Cuda |
dadfa4593d22e3f3e3c3f4e14f08d5f9340fe4f6 | adjust to new arrays | toxa81/sirius,electronic-structure/sirius,electronic-structure/sirius,toxa81/sirius,electronic-structure/sirius,toxa81/sirius,electronic-structure/sirius,dithillobothrium/SIRIUS,electronic-structure/sirius,dithillobothrium/SIRIUS,toxa81/sirius,dithillobothrium/SIRIUS,electronic-structure/sirius,toxa81/sirius,dithillobo... | src/Kernels/generate_phase_factors.cu | src/Kernels/generate_phase_factors.cu | #include "../SDDK/GPU/cuda_common.h"
__global__ void generate_phase_factors_gpu_kernel
(
int num_gvec_loc,
int num_atoms,
double const* atom_pos,
int const* gvec,
cuDoubleComplex* phase_factors
)
{
int ia = blockIdx.y;
int igloc = blockIdx.x * blockDim.x + threadIdx.x;
if (igloc < n... | #include "../SDDK/GPU/cuda_common.h"
__global__ void generate_phase_factors_gpu_kernel
(
int num_gvec_loc,
double const* atom_pos,
int const* gvec,
cuDoubleComplex* phase_factors
)
{
int ia = blockIdx.y;
int igloc = blockIdx.x * blockDim.x + threadIdx.x;
if (igloc < num_gvec_loc)
{
... | bsd-2-clause | Cuda |
e2b6abba3c8232af77ec32bbbfc9a0a0a280affc | make testevents2 try a bunch of times | hughperkins/coriander,hughperkins/cuda-on-cl,hughperkins/coriander,hughperkins/coriander,hughperkins/cuda-on-cl,hughperkins/cuda-on-cl,hughperkins/cuda-on-cl,hughperkins/coriander | test/cocl/testevents2.cu | test/cocl/testevents2.cu | // tests cuEventCreate
#include <iostream>
#include <memory>
using namespace std;
#include <cuda.h>
__global__ void longKernel(float *data, int N, float value) {
for(int i = 0; i < N; i++) {
data[i] += value;
}
}
int main(int argc, char *argv[]) {
int N = 202400; // * 1024;
float *hostfloa... | // tests cuEventCreate
#include <iostream>
#include <memory>
using namespace std;
#include <cuda.h>
__global__ void longKernel(float *data, int N, float value) {
for(int i = 0; i < N; i++) {
data[i] += value;
}
}
int main(int argc, char *argv[]) {
int N = 202400; // * 1024;
float *hostfloa... | apache-2.0 | Cuda |
4feb40c8786243f59cbdfeaccb30a0d567fc16ae | update cuda kernel | toxa81/sirius,electronic-structure/sirius,dithillobothrium/SIRIUS,toxa81/sirius,electronic-structure/sirius,dithillobothrium/SIRIUS,toxa81/sirius,electronic-structure/sirius,electronic-structure/sirius,electronic-structure/sirius,toxa81/sirius,toxa81/sirius,dithillobothrium/SIRIUS,toxa81/sirius,dithillobothrium/SIRIUS,... | src/Kernels/add_pw_ekin.cu | src/Kernels/add_pw_ekin.cu | #include "../SDDK/GPU/cuda_common.h"
__global__ void add_pw_ekin_gpu_kernel(int num_gvec__,
cuDoubleComplex const* phi__,
double const* pw_ekin__,
cuDoubleComplex const* vphi__,
... | #include "../SDDK/GPU/cuda_common.h"
__global__ void add_pw_ekin_gpu_kernel(int num_gvec__,
double const* pw_ekin__,
cuDoubleComplex const* vphi__,
cuDoubleComplex* hphi__)
{
int ig = blockIdx.x * b... | bsd-2-clause | Cuda |
921b36bf0920ab6e7ca89e5d3095209707f04797 | Revise SoftRelu | sxjscience/mxnet,sxjscience/mxnet,sxjscience/mxnet,sxjscience/mxnet,sxjscience/mxnet,sxjscience/mxnet,sxjscience/mxnet,sxjscience/mxnet,sxjscience/mxnet | src/operator/activation.cu | src/operator/activation.cu | /*!
* Copyright (c) 2015 by Contributors
* \file activation.cu
* \brief
* \author Bing Xu
*/
#include "./activation-inl.h"
#include "./mshadow_op.h"
#if MXNET_USE_CUDNN == 1
#include "./cudnn_activation-inl.h"
#endif
namespace mxnet {
namespace op {
template<>
Operator *CreateOp<gpu>(ActivationParam param, int dty... | /*!
* Copyright (c) 2015 by Contributors
* \file activation.cu
* \brief
* \author Bing Xu
*/
#include "./activation-inl.h"
#include "./mshadow_op.h"
#if MXNET_USE_CUDNN == 1
#include "./cudnn_activation-inl.h"
#endif
namespace mxnet {
namespace op {
template<>
Operator *CreateOp<gpu>(ActivationParam param, int dty... | apache-2.0 | Cuda |
e14ce3c9168c1b7ece220c6238d93f643d9a316b | Update host sync path to use new API. | NVlabs/cub,NVIDIA/cub,NVlabs/CUB | cub/detail/device_synchronize.cuh | cub/detail/device_synchronize.cuh | /*
* Copyright 2021 NVIDIA Corporation
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law ... | /*
* Copyright 2021 NVIDIA Corporation
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law ... | bsd-3-clause | Cuda |
057d200a406888d236b9a3ab1d2f646c4eb01c49 | load text | amunmt/marian,afaji/Marian,emjotde/Marian,emjotde/amunn,DianaDespa/marian-train,emjotde/amunn,amunmt/marian,afaji/Marian,afaji/Marian,DianaDespa/marian-train,marian-nmt/marian-train,emjotde/amunmt,marian-nmt/marian-train,marian-nmt/marian-train,emjotde/amunn,emjotde/amunmt,emjotde/amunmt,emjotde/amunn,marian-nmt/marian... | src/test.cu | src/test.cu |
#include "marian.h"
using namespace std;
int main(int argc, char** argv) {
using namespace marian;
using namespace keywords;
/*
Expr x = input(shape={whatevs, 784}, name="X");
Expr y = input(shape={whatevs, 10}, name="Y");
Expr w = param(shape={784, 10}, name="W0");
Expr b = param(shape={1, 10},... |
#include "marian.h"
using namespace std;
int main(int argc, char** argv) {
using namespace marian;
using namespace keywords;
/*
Expr x = input(shape={whatevs, 784}, name="X");
Expr y = input(shape={whatevs, 10}, name="Y");
Expr w = param(shape={784, 10}, name="W0");
Expr b = param(shape={1, 10},... | mit | Cuda |
dbbd36cd943b25f9ac78a978b77ed6ae6cae18bf | Mark the debug.cu tests as KNOWN_FAILURES on OSX | GrimDerp/thrust,dachziegel/thrust,jaredhoberock/thrust,raygit/thrust,raygit/thrust,thvasilo/thrust,Ricardo666666/thrust,thvasilo/thrust,zhenglaizhang/thrust,zeryx/thrust,egaburov/thrust,sdalton1/thrust,xiongzhanblake/thrust,Ricardo666666/thrust,GrimDerp/thrust,dachziegel/thrust,thrust/thrust,zeryx/thrust,andrewcorrigan... | testing/debug.cu | testing/debug.cu | #define THRUST_DEBUG 1
#include <unittest/unittest.h>
#include <thrust/device_ptr.h>
#include <thrust/transform.h>
#include <thrust/reduce.h>
#include <thrust/scan.h>
#include <thrust/sort.h>
#include <thrust/system_error.h>
#if THRUST_DEVICE_BACKEND == THRUST_DEVICE_BACKEND_CUDA
void TestTransformNullPtr(void)
{
#i... | #define THRUST_DEBUG 1
#include <unittest/unittest.h>
#include <thrust/device_ptr.h>
#include <thrust/transform.h>
#include <thrust/reduce.h>
#include <thrust/scan.h>
#include <thrust/sort.h>
#include <thrust/system_error.h>
#if THRUST_DEVICE_BACKEND == THRUST_DEVICE_BACKEND_CUDA
void TestTransformNullPtr(void)
{
... | apache-2.0 | Cuda |
2b4de70835d47df11ccc3deb22cb95edec540d8f | fix header | SLACKHA/pyJac,kyleniemeyer/pyJac,SLACKHA/pyJac,kyleniemeyer/pyJac | pyjacob.cuh | pyjacob.cuh | /* wrapper to translate to cuda arrays */
#ifndef CU_PYJAC_HEAD
#define CU_PYJAC_HEAD
void run(int num, const double* pres, const double* mass_frac,
double* conc, double* fwd_rxn_rates, double* rev_rxn_rates,
double* pres_mod, double* spec_rates, double* dy, double* jac,
bool eval_rates);
#endif | /* wrapper to translate to cuda arrays */
#ifndef CU_PYJAC_HEAD
#define CU_PYJAC_HEAD
void run(int num, const double* pres, const double* mass_frac,
double* conc, double* fwd_rxn_rates, double* rev_rxn_rates,
double* pres_mod, double* spec_rates, double* dy, double* jac);
#endif | mit | Cuda |
1146cc4f68135dca5a7a9f5b2a7eb19c6c03954e | Use min disparity in horizontal path aggregation test | fixstars-jp/libSGM,fixstars/libSGM | test/horizontal_path_aggregation_test.cu | test/horizontal_path_aggregation_test.cu | #include <gtest/gtest.h>
#include "horizontal_path_aggregation.hpp"
#include "internal.h"
#include "path_aggregation_test.hpp"
#include "generator.hpp"
#include "test_utility.hpp"
#include "debug.hpp"
class HorizontalPathAggregation : public testing::TestWithParam<std::tuple<int, int, int>>
{
public:
int min_disp_;
... | #include <gtest/gtest.h>
#include "horizontal_path_aggregation.hpp"
#include "path_aggregation_test.hpp"
#include "generator.hpp"
#include "test_utility.hpp"
#include "debug.hpp"
TEST(HorizontalPathAggregationTest, RandomLeft2Right){
static constexpr size_t width = 631, height = 479, disparity = 128;
static constex... | apache-2.0 | Cuda |
81d106c7742eaf6c37fad3b21d7ac45cd1f99e95 | Fix implicit-device-lambda.cu after r282911. | apple/swift-clang,llvm-mirror/clang,apple/swift-clang,apple/swift-clang,llvm-mirror/clang,llvm-mirror/clang,apple/swift-clang,apple/swift-clang,apple/swift-clang,llvm-mirror/clang,llvm-mirror/clang,apple/swift-clang,apple/swift-clang,llvm-mirror/clang,llvm-mirror/clang,llvm-mirror/clang,apple/swift-clang,apple/swift-cl... | test/SemaCUDA/implicit-device-lambda.cu | test/SemaCUDA/implicit-device-lambda.cu | // RUN: %clang_cc1 -std=c++11 -fcuda-is-device -verify -fsyntax-only -verify-ignore-unexpected=warning -verify-ignore-unexpected=note %s
// RUN: %clang_cc1 -std=c++11 -verify -fsyntax-only -verify-ignore-unexpected=warning -verify-ignore-unexpected=note %s
#include "Inputs/cuda.h"
__device__ void device_fn() {
auto... | // RUN: %clang_cc1 -std=c++11 -fcuda-is-device -verify -fsyntax-only -verify-ignore-unexpected=note %s
// RUN: %clang_cc1 -std=c++11 -verify -fsyntax-only -verify-ignore-unexpected=note %s
#include "Inputs/cuda.h"
__device__ void device_fn() {
auto f1 = [&] {};
f1(); // implicitly __device__
auto f2 = [&] __de... | apache-2.0 | Cuda |
Subsets and Splits
No community queries yet
The top public SQL queries from the community will appear here once available.